#
# spec file for package vlc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libvlc 5
%define libvlccore 8
%define conflicts vlc-beta
%if 0%{?suse_version} >= 1200
%bcond_without gstreamer
%else
%bcond_with gstreamer
%endif
%ifarch %arm
%bcond_without opengles
%else
%bcond_with opengles
%endif
# Fluidsynth plugin is known to cause strange crashes here and there - disable it for now (2014-10-07, DimStar)
%bcond_with fluidsynth
# VNC support - the module is not really usable in most cases tested so far (e.g. against qemu-kvm -vnc :xx)
%bcond_with vnc
Name:           vlc
Version:        2.2.6
Release:        10.5
Summary:        Graphical media player
License:        GPL-2.0+ AND LGPL-2.1+
Group:          Productivity/Multimedia/Video/Players
Url:            http://www.videolan.org
Source:         http://download.videolan.org/%{name}/%{version}/%{name}-%{version}.tar.xz
# Add vlc.changes as source, so we can reproducibly extract the date from it during build
Source1:        %{name}.changes
Source2:        %{name}-rpmlintrc
Source3:        %{name}.appdata.xml
Patch3:         0001-no-return-in-non-void.patch
Patch4:         vlc-2.2.0-fix_deinterlace_mmx.patch
# PATCH-FIX-UPSTREAM vlc-support-qt5.5.patch dimstar@opensuse.org -- The Qt 5.5 packages in Leap and Tumbleweed are patched. Other dists don't have Qt 5.5 yet. Patch from upstream, reverse applied
Patch5:         vlc-support-qt5.5.patch
# PATCH-FIX-UPSTREAM vlc-gcc6-buildfixes.patch dimstar@opensuse.org -- A collection of upstream commits to fix build with gcc6
Patch6:         vlc-gcc6-buildfixes.patch
Patch7:         vlc.a52.patch
# PATCH-FIX-OPENSUSE vlc-projectM-qt5.patch -- link to libprojectM-qt5
Patch8:         vlc-projectM-qt5.patch
Patch9:         vlc-flac-heap-overflow.patch
BuildRequires:  Mesa-devel
BuildRequires:  SDL-devel >= 1.2.10
BuildRequires:  aalib-devel
BuildRequires:  alsa-devel >= 1.0.24
BuildRequires:  avahi-devel >= 0.6
BuildRequires:  dirac-devel
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  freetype2
BuildRequires:  fribidi-devel
BuildRequires:  gettext-devel
BuildRequires:  git
BuildRequires:  gtk2-devel
BuildRequires:  libavc1394-devel >= 0.5.3
BuildRequires:  libcddb-devel >= 0.9.5
BuildRequires:  libcdio-devel >= 0.78.2
BuildRequires:  libdc1394-devel >= 2.1.0
BuildRequires:  libdvbpsi-devel >= 1.0.0
BuildRequires:  libgcrypt-devel
BuildRequires:  libidn-devel
BuildRequires:  libjack-devel >= 1.9.7
BuildRequires:  libjpeg-devel
BuildRequires:  libkate-devel >= 0.3.0
BuildRequires:  libnotify-devel
BuildRequires:  libogg-devel >= 1.0
BuildRequires:  libopus-devel >= 1.0.3
BuildRequires:  libraw1394 >= 2.0.1
BuildRequires:  librsvg-devel >= 2.9.0
BuildRequires:  libsamplerate-devel
BuildRequires:  libshout-devel >= 2.1
BuildRequires:  libsmbclient-devel
BuildRequires:  libssh2-devel
BuildRequires:  libtheora-devel >= 1.0
BuildRequires:  libtool
BuildRequires:  libudev-devel >= 142
BuildRequires:  libvorbis-devel >= 1.1
BuildRequires:  libvpx-devel
BuildRequires:  libxml2-devel >= 2.5
BuildRequires:  lirc-devel
BuildRequires:  live555-devel >= 2015.01.27
BuildRequires:  lua-devel >= 5.1
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  schroedinger-devel >= 1.0.10
BuildRequires:  slang-devel
BuildRequires:  speex-devel >= 1.0.5
BuildRequires:  update-desktop-files
BuildRequires:  vcdimager-devel
BuildRequires:  xosd-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(libavcodec) >= 55.26.0
BuildRequires:  pkgconfig(libavformat) >= 53.21.0
BuildRequires:  pkgconfig(libavutil) >= 52.4.0
BuildRequires:  pkgconfig(libmodplug) >= 0.8.4
Requires:       %{name}-noX = %{version}-%{release}
Requires:       %{name}-qt = %{version}-%{release}
# We need the noX package first, as it contains vlc-cache-gen
PreReq:         %{name}-noX
Conflicts:      %{conflicts}
Obsoletes:      %{name}-gnome <= %{version}
BuildConflicts: pkgconfig(libavutil) >= 55
%if %{with gstreamer}
BuildRequires:  pkgconfig(gstreamer-app-1.0)
%endif
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
BuildRequires:  flac-devel
%endif
%if 0%{?suse_version} >= 1310
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
BuildRequires:  pkgconfig(Qt5X11Extras)
# for some reason libXi-devel is explicitly needed on Leap 42.1, otherwise the build fails...
BuildRequires:  pkgconfig(xi)
%endif
%else
BuildRequires:  libqt4-devel >= 4.6.0
%endif
%if 0%{?suse_version} > 1110
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  libv4l-devel
BuildRequires:  pkgconfig(caca) >= 0.99.beta14
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(xcb) >= 1.6
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-randr) >= 1.3
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-xv) >= 1.1.90.1
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(zvbi-0.2) >= 0.2.28
%endif
%if 0%{?suse_version} >= 1140 && 0%{?suse_version} != 1315 || 0%{?BUILD_ORIG}
BuildRequires:  pkgconfig(libswscale)
%endif
%if 0%{?suse_version} > 1110
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
BuildRequires:  pkgconfig(SDL_image) >= 1.2.10
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(opencv) > 2.0
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(libprojectM-qt5) >= 2.0.0
%else
BuildRequires:  pkgconfig(libprojectM) >= 2.0.0
%endif
%endif
%endif
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
BuildRequires:  libmatroska-devel
BuildRequires:  pkgconfig(dvdnav) > 4.9.0
BuildRequires:  pkgconfig(dvdread) > 4.9.0
BuildRequires:  pkgconfig(libass) >= 0.9.8
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libmtp) >= 1.0.0
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(taglib) >= 1.9
%endif
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(dbus-1) >= 1.6.0
BuildRequires:  pkgconfig(gnutls) >= 3.2.0
BuildRequires:  pkgconfig(libbluray) >= 0.3.0
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(xcb-keysyms) >= 0.3.4
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
%if 0%{?suse_version} < 1330 && ( 0%{?sle_version} < 120200 || 0%{?is_opensuse} < 1 )
BuildRequires:  pkgconfig(freerdp) >= 1.0.1
%endif
%if %{with vnc}
BuildRequires:  pkgconfig(libvncclient) >= 0.9.9
%endif
%if %{with fluidsynth}
BuildRequires:  pkgconfig(fluidsynth) >= 1.1.2
%endif
%if 0%{?suse_version} != 1315
BuildRequires:  pkgconfig(libchromaprint) >= 0.6.0
%endif
%endif
%if 0%{?suse_version} >= 1320
BuildRequires:  pkgconfig(ncursesw)
%endif
%if (0%{?suse_version} == 1330) || (0%{?suse_version} == 1315 && 0%{?sle_version} >= 120200)
# for TW, we favor ffmpeg2-devel. Older distros have ffmpeg 2.x intree
BuildRequires:  ffmpeg-2-libavcodec-devel
%endif
# Those are dependencies which are NOT provided in openSUSE, mostly for legal reasons.
%if 0%{?BUILD_ORIG}
BuildRequires:  faad2-devel
# Disabled for now - VideoLAN repo needs to catch up
BuildRequires:  liba52-devel
BuildRequires:  libfaac-devel
# Disabled for now - VideoLAN repo needs to catch up
BuildRequires:  libmad-devel
BuildRequires:  libxvidcore-devel
BuildRequires:  pkgconfig(libdca) >= 0.0.5
BuildRequires:  pkgconfig(libmpeg2) > 0.3.2
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(x264) >= 0.8.6
# Disabled for now - VideoLAN repo needs to catch up
#BuildRequires:  pkgconfig(x265)
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(vdpau) >= 0.6
%endif
%endif

%description
VLC media player is a multimedia player for many
audio and video files and formats (such as MPEG, DivX, mp3, ogg, ...)
as well as DVDs, VCDs, and various streaming protocols.
It can also be used as a server to stream in unicast or multicast
in IPv4 or IPv6 on a high-bandwidth network.

%if 0%{?BUILD_ORIG}
Note that the actual support is provided through ffmpeg and gstreamer
libraries, which may not have all codecs enabled that were just named.
%endif

%package devel
Summary:        Development files for the VLC media player system
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
These development headers are required if you plan on coding against VLC.

%package -n libvlc%{libvlc}
Summary:        Shared code for the VLC media player program
Group:          System/Libraries

%description -n libvlc%{libvlc}
This subpackage contains libraries that are part of VLC.

%package -n libvlccore%{libvlccore}
Summary:        Shared code for the VLC media player program
Group:          System/Libraries

%description -n libvlccore%{libvlccore}
This subpackage contains libraries that are part of VLC.

%package noX
Summary:        VLC without X dependencies
Group:          Productivity/Multimedia/Video/Players
Requires:       libvlc%{libvlc} = %{version}-%{release}
Requires:       libvlccore%{libvlccore} = %{version}-%{release}
# This is a hack only due to libbluray not having versioned symbols as well as
# having a strange ABI/API break between 0.3 and 0.7
%requires_ge    libbluray1
Recommends:     %{name}-codecs
# lang subpackage
Recommends:     %{name}-lang
Recommends:     libdvdcss
Conflicts:      %{conflicts}-noX
# The lang-package was renamed to vlc-lang to assist AppStream building
Obsoletes:      %{name}-noX-lang

%description noX
This package of VLC contains the bare requirements you need to install.
There is no graphical user interface included, thus it is also perfectly
suitable for server installations, for example, to run a streaming server.

Should you decide to install the GUI modules, %{name}-noX will stay
installed as a dependency.

# we can't use %%lang_package, as we need a different dependency
# boo#1012556
# but the package name has to stay vlc-lang, as otherise the software centers
# (AppStream based) can't see vlc being translated (vlc is the one listed in SC
# not vlc-noX)
%package lang
Summary:        Translations for package %{name}
# We do not want to require vlc, which is GUI based, but only vlc-noX
Group:          System/Localization
Requires:       %{name}-noX = %{version}
Supplements:    packageand(bundle-lang-other:%{name}-noX)
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%package codec-gstreamer
Summary:        GStreamer integration for the VLC media player
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name}-noX = %{version}
Supplements:    packageand(%{name}-noX:%(rpm --qf "%%{name}" -qf $(readlink -f %{_libdir}/libgstapp-1.0.so)))

%description codec-gstreamer
This package enhances the functionality of the VLC media player by
using GStreamer and its submodules as a backend to decode streams.

%if 0%{?BUILD_ORIG}
%package codecs
Summary:        Additional codecs for the VLC media player
Group:          Productivity/Multimedia/Video/Players
# We require the unrestricted libavcodec - same ABI version we linked
Requires:       %(rpm --qf "%%{name}" -qf $(readlink -f %{_libdir}/libavcodec.so))(unrestricted)
Requires:       %{name}-noX = %{version}
Supplements:    %{name}-noX

%description codecs
This package enhances the functionality of the VLC media player by
codecs that are not available in the stock openSUSE distribution.
%endif

%package qt
Summary:        Qt interface for the VLC media player
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name}-noX = %{version}-%{release}
Conflicts:      %{conflicts}-qt
%if 0%{?suse_version} >= 1310
Supplements:    packageand(%{name}-noX:libqt5)
%else
Supplements:    packageand(%{name}-noX:libqt4)
%endif

%description qt
This subpackage provides a Qt interface for VLC and selects it by
default when `vlc` is invoked from an X session.

%prep
echo '********* ENTERED PREP PHASE ********'
date
%setup -q
%patch3 -p1
%if 0%{?suse_version} == 1110
%ifarch %ix86
%patch4
%endif
%endif
%if 0%{?suse_version} > 1310
# openSUSE Leap and Tumbleweed have Qt 5.5.x, but with the required patch applied
# openSUSE 13.2 (also > 1310) comes with Qt 5.3, so is not affected, but the patch does not harm
%patch5 -p1 -R
%endif
if [ $(gcc -dumpversion) -ge 6 ]; then
%patch6 -p1
fi
%patch7 -p1
%if 0%{?suse_version} > 1320
%patch8 -p1
%endif
%patch9 -p1

### Fix up sources for LUA 5.3
if pkg-config --atleast-version 5.3 lua; then
  sed -i 's/luaL_optint/(int)&eger/'         modules/lua/libs/{net,osd,volume}.c
fi

### And LUA 5.3.1 has some more API changes
if pkg-config --atleast-version 5.3.1 lua; then
  sed -i 's/luaL_checkint(/(int)luaL_checkinteger(/' \
    modules/lua/{demux,libs/{configuration,net,osd,playlist,stream,variables,volume}}.c
fi

# We do not rely on contrib but make use of system libraries
rm -rf contrib
# fix builddate info
# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{SOURCE1} '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{SOURCE1} '+%%b %%e %%Y')
sed -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" -i modules/gui/qt4/dialogs/help.cpp src/config/help.c
sed -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -i modules/gui/qt4/dialogs/help.cpp src/config/help.c

echo '********* ENDED PREP PHASE *********'
date

%build
echo '********* BOOTSTRAPPING *********'
date
export CFLAGS="%{optflags} -fPIE"
export CXXFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%if 0%{?suse_version} > 1140
./bootstrap
%endif
%configure \
   --disable-dependency-tracking        \
   --enable-aa                          \
   --enable-alsa                        \
   --enable-dvbpsi                      \
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
   --enable-dvdnav                      \
   --enable-dvdread                     \
   --enable-flac                        \
%endif
   --enable-fast-install                \
%if 0%{?suse_version} > 1140 && 0%{?suse_version} < 1330 && ( 0%{?sle_version} < 120200 || 0%{?is_opensuse} < 1 )
   --enable-freerdp                     \
%endif
   --enable-freetype                    \
   --enable-fribidi                     \
   --disable-gnomevfs                   \
%if 0%{?suse_version} > 1140
   --enable-gnutls                      \
%endif
   --enable-httpd                       \
   --enable-jack                        \
%if 0%{?suse_version} <= 1140
   --disable-jpeg                       \
%endif
   --enable-kate                        \
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
   --enable-libass                      \
%endif
   --enable-libcddb                     \
%if 0%{?suse_version} > 1110
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
   --enable-opencv                      \
%endif
%endif
%if 0%{?suse_version} <= 1140
   --disable-mmx                        \
   --disable-sse                        \
%endif
   --enable-sftp                        \
   --disable-svgdec                     \
%if 0%{?suse_version} >= 1140 && 0%{?suse_version} != 1315 || 0%{?BUILD_ORIG}
   --enable-swscale                     \
%else
   --disable-swscale                    \
%endif
%if 0%{?BUILD_ORIG}
   --enable-libmpeg2                    \
   --enable-mad                         \
   --enable-postproc                    \
   --enable-faad                        \
   --enable-a52                         \
   --enable-dca                         \
%else
   --disable-libmpeg2                   \
   --disable-mad                        \
   --disable-postproc                   \
   --disable-faad                       \
   --disable-a52                        \
   --disable-dca                        \
%endif
   --enable-avcodec                     \
   --enable-lirc                        \
   --enable-live555                     \
   --enable-lua                         \
   --enable-mkv                         \
   --enable-mod                         \
   --enable-ogg                         \
   --enable-optimizations               \
   --disable-oss                        \
%if 0%{?suse_version} > 1140
   --enable-pulse                       \
%endif
   --enable-realrtsp                    \
   --enable-sout                        \
   --enable-speex                       \
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
   --enable-taglib                      \
%endif
   --enable-theora                      \
   --enable-v4l2                        \
   --enable-vcd                         \
   --enable-vcdx                        \
   --enable-vorbis                      \
   --disable-x265                       \
%if 0%{?suse_version} > 1110
   --enable-xcb                         \
%else
   --disable-xcb                        \
%endif
%if %{with opengles}
  --enable-gles2                        \
%endif
  --disable-atmo                        \
%if 0%{?suse_version} > 1140 && 0%{?BUILD_ORIG}
   --enable-vdpau                       \
%else
   --disable-vdpau                      \
%endif
   --enable-xvideo                      \
   --with-default-font=%{_datadir}/fonts/truetype/FreeSerifBold.ttf \
   --with-default-monospace-font=%{_datadir}/fonts/truetype/FreeMono.ttf
echo '********* FINISHED CONFIGURE *********'
date

# post config patches, not very nice but we don't have automake

%if 0%{?suse_version} == 1110
# replaces ustar patch
sed -e 's/tar cvv/tar cvv --format=ustar/' -i share/Makefile
%endif

# make sure the build hostname is not embedded in the binaries -- or we'll
# continuously republish packages -- seife
### ONLY REMOVE THIS IF YOU KNOW WHAT YOU ARE DOING!
sed -i 's/^#define.*VLC_COMPILE_HOST.*/#define VLC_COMPILE_HOST "obs-build"/' config.h

make %{?_smp_mflags}

%install
echo '********* ENTERED INSTALL PHASE *********'
date
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mkdir -p %{buildroot}/%{_datadir}/pixmaps
# We need a full copy, as the pixmap icon goes to the -noX package
cp %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/vlc.png %{buildroot}/%{_datadir}/pixmaps/vlc.png
#Make vlc available in Plasma 5 device notifier
mkdir %{buildroot}%{_datadir}/solid
mkdir %{buildroot}%{_datadir}/solid/actions
cp %{buildroot}%{_datadir}/kde4/apps/solid/actions/vlc-open*.desktop %{buildroot}%{_datadir}/solid/actions/
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file vlc AudioVideo Audio Video Player
%fdupes %{buildroot}%{_datadir}/vlc
# remove duplicate file
rm %{buildroot}/%{_datadir}/vlc/lua/http/requests/README.txt
# add missing manfiles
for i in ?vlc; do
    pushd %{buildroot}/%{_mandir}/man1
    ln -s vlc.1 $i.1
    popd
done

# don't ship hevc-related modules even if probably overkill for legal purposes
%if ! 0%{?BUILD_ORIG}
rm %{buildroot}/%{_libdir}/vlc/plugins/demux/libhevc_plugin.so
rm %{buildroot}/%{_libdir}/vlc/plugins/packetizer/libpacketizer_hevc_plugin.so
%endif

# clean up some lang issues...
for lang in ach an cgg co ff tet ks_IN; do
  rm -rf %{buildroot}%{_datadir}/locale/$lang
done
%find_lang vlc

#Install appdata file
install -Dm0644 %{SOURCE3} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%post
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins

%post -n %{name}-noX
/sbin/ldconfig
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins

%postun -n %{name}-noX -p /sbin/ldconfig

%post -n libvlc%{libvlc} -p /sbin/ldconfig
%postun -n libvlc%{libvlc} -p /sbin/ldconfig

%post -n libvlccore%{libvlccore} -p /sbin/ldconfig
%postun -n libvlccore%{libvlccore} -p /sbin/ldconfig

%post -n %{name}-qt
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins

%if 0%{?BUILD_ORIG}
%post -n %{name}-codecs
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins
%endif

%files
%defattr(-,root,root)
# The presence of the .desktop file is what gives AppStream the
# hint of which package to add in the appstore... 'vlc' is the place to be
%{_datadir}/applications/vlc.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
# The icon is the one referenced by the .desktop file
%{_datadir}/pixmaps/vlc.png
%{_bindir}/svlc
%{_datadir}/icons/hicolor/*/apps/vlc*
%dir %{_datadir}/kde4
%dir %{_datadir}/kde4/apps
%{_datadir}/kde4/apps/solid
%{_datadir}/solid
%exclude %{_libdir}/vlc/libcompat.a
%{_mandir}/man1/svlc*
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/codec/liblibass_plugin.so
%endif
%if 0%{?suse_version} > 1110
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
%{_libdir}/vlc/plugins/codec/libsdl_image_plugin.so
%endif
%endif
%{_libdir}/vlc/plugins/notify/libnotify_plugin.so
%{_libdir}/vlc/plugins/video_filter/libremoteosd_plugin.so
%{_libdir}/vlc/plugins/text_renderer/libfreetype_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/video_splitter/libpanoramix_plugin.so
%{_libdir}/vlc/plugins/video_output/libxcb_glx_plugin.so
%endif
%if %{with opengles}
%{_libdir}/vlc/plugins/video_output/libgles2_plugin.so
%endif
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/video_output/libegl_x11_plugin.so
%endif
%{_libdir}/vlc/plugins/visualization/libglspectrum_plugin.so
%{_libdir}/vlc/plugins/video_output/libaa_plugin.so
%if 0%{?suse_version} > 1110
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
%{_libdir}/vlc/plugins/visualization/libprojectm_plugin.so
%endif
%endif

%files lang -f vlc.lang
%defattr(-,root,root)

%files noX
%defattr(-,root,root)
%doc %{_datadir}/doc/vlc/
%doc NEWS AUTHORS COPYING THANKS README
%{_bindir}/cvlc
%if 0%{?suse_version} >= 1320
%{_bindir}/nvlc
%{_mandir}/man1/nvlc*
%endif
%{_bindir}/rvlc
%{_bindir}/vlc
%{_bindir}/vlc-wrapper
%{_datadir}/vlc/
%{_mandir}/man1/cvlc*
%{_mandir}/man1/rvlc*
%{_mandir}/man1/vlc*
# Own the file.. but it's an auto-generated file, so ghost it.
%ghost %{_libdir}/vlc/plugins/plugins.dat
%dir %{_libdir}/vlc
%dir %{_libdir}/vlc/lua
%dir %{_libdir}/vlc/lua/extensions
%dir %{_libdir}/vlc/lua/intf
%dir %{_libdir}/vlc/lua/intf/modules
%dir %{_libdir}/vlc/lua/meta
%dir %{_libdir}/vlc/lua/meta/art
%dir %{_libdir}/vlc/lua/meta/fetcher
%dir %{_libdir}/vlc/lua/meta/reader
%dir %{_libdir}/vlc/lua/modules
%dir %{_libdir}/vlc/lua/playlist
%dir %{_libdir}/vlc/lua/sd
%dir %{_libdir}/vlc/plugins
%dir %{_libdir}/vlc/plugins/access
%dir %{_libdir}/vlc/plugins/access_output
%dir %{_libdir}/vlc/plugins/audio_filter
%dir %{_libdir}/vlc/plugins/audio_mixer
%dir %{_libdir}/vlc/plugins/audio_output
%dir %{_libdir}/vlc/plugins/codec
%dir %{_libdir}/vlc/plugins/control
%dir %{_libdir}/vlc/plugins/demux
%dir %{_libdir}/vlc/plugins/gui
%dir %{_libdir}/vlc/plugins/lua
%dir %{_libdir}/vlc/plugins/meta_engine
%dir %{_libdir}/vlc/plugins/misc
%dir %{_libdir}/vlc/plugins/mux
%dir %{_libdir}/vlc/plugins/notify
%dir %{_libdir}/vlc/plugins/packetizer
%dir %{_libdir}/vlc/plugins/services_discovery
%dir %{_libdir}/vlc/plugins/stream_filter
%dir %{_libdir}/vlc/plugins/stream_out
%dir %{_libdir}/vlc/plugins/text_renderer
%dir %{_libdir}/vlc/plugins/video_chroma
%dir %{_libdir}/vlc/plugins/video_filter
%dir %{_libdir}/vlc/plugins/video_output
%dir %{_libdir}/vlc/plugins/video_splitter
%dir %{_libdir}/vlc/plugins/visualization
# Files explicitly listed... so we are in full control of what goes to -noX, -codec or the X-depending pkg.
%{_libdir}/vlc/vlc-cache-gen
%{_libdir}/vlc/lua/extensions/VLSub.luac
%{_libdir}/vlc/lua/intf/cli.luac
%{_libdir}/vlc/lua/intf/dummy.luac
%{_libdir}/vlc/lua/intf/dumpmeta.luac
%{_libdir}/vlc/lua/intf/http.luac
%{_libdir}/vlc/lua/intf/luac.luac
%{_libdir}/vlc/lua/intf/modules/host.luac
%{_libdir}/vlc/lua/intf/modules/httprequests.luac
%{_libdir}/vlc/lua/intf/telnet.luac
%{_libdir}/vlc/lua/meta/art/00_musicbrainz.luac
%{_libdir}/vlc/lua/meta/art/01_googleimage.luac
%{_libdir}/vlc/lua/meta/art/02_frenchtv.luac
%{_libdir}/vlc/lua/meta/art/03_lastfm.luac
%{_libdir}/vlc/lua/meta/fetcher/tvrage.luac
%{_libdir}/vlc/lua/meta/reader/filename.luac
%{_libdir}/vlc/lua/modules/common.luac
%{_libdir}/vlc/lua/modules/dkjson.luac
%{_libdir}/vlc/lua/modules/sandbox.luac
%{_libdir}/vlc/lua/modules/simplexml.luac
%{_libdir}/vlc/lua/playlist/anevia_streams.luac
%{_libdir}/vlc/lua/playlist/anevia_xml.luac
%{_libdir}/vlc/lua/playlist/appletrailers.luac
%{_libdir}/vlc/lua/playlist/bbc_co_uk.luac
%{_libdir}/vlc/lua/playlist/break.luac
%{_libdir}/vlc/lua/playlist/canalplus.luac
%{_libdir}/vlc/lua/playlist/cue.luac
%{_libdir}/vlc/lua/playlist/dailymotion.luac
%{_libdir}/vlc/lua/playlist/extreme.luac
%{_libdir}/vlc/lua/playlist/france2.luac
%{_libdir}/vlc/lua/playlist/googlevideo.luac
%{_libdir}/vlc/lua/playlist/jamendo.luac
%{_libdir}/vlc/lua/playlist/joox.luac
%{_libdir}/vlc/lua/playlist/katsomo.luac
%{_libdir}/vlc/lua/playlist/koreus.luac
%{_libdir}/vlc/lua/playlist/lelombrik.luac
%{_libdir}/vlc/lua/playlist/liveleak.luac
%{_libdir}/vlc/lua/playlist/metacafe.luac
%{_libdir}/vlc/lua/playlist/metachannels.luac
%{_libdir}/vlc/lua/playlist/mpora.luac
%{_libdir}/vlc/lua/playlist/pinkbike.luac
%{_libdir}/vlc/lua/playlist/pluzz.luac
%{_libdir}/vlc/lua/playlist/rockbox_fm_presets.luac
%{_libdir}/vlc/lua/playlist/soundcloud.luac
%{_libdir}/vlc/lua/playlist/vimeo.luac
%{_libdir}/vlc/lua/playlist/youtube.luac
%{_libdir}/vlc/lua/playlist/youtube_homepage.luac
%{_libdir}/vlc/lua/playlist/zapiks.luac
%{_libdir}/vlc/lua/sd/fmc.luac
%{_libdir}/vlc/lua/sd/icast.luac
%{_libdir}/vlc/lua/sd/icecast.luac
%{_libdir}/vlc/lua/sd/jamendo.luac
%{_libdir}/vlc/plugins/access/libaccess_alsa_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_bd_plugin.so
%{_libdir}/vlc/plugins/access/libftp_plugin.so
%{_libdir}/vlc/plugins/access/libhttp_plugin.so
%{_libdir}/vlc/plugins/access/libimem_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_jack_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_mms_plugin.so
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/access/libaccess_mtp_plugin.so
%endif
%{_libdir}/vlc/plugins/access/libaccess_realrtsp_plugin.so
%{_libdir}/vlc/plugins/access/libattachment_plugin.so
%{_libdir}/vlc/plugins/access/libavio_plugin.so
%{_libdir}/vlc/plugins/access/libcdda_plugin.so
%{_libdir}/vlc/plugins/access/libdtv_plugin.so
%{_libdir}/vlc/plugins/access/libdvb_plugin.so
%{_libdir}/vlc/plugins/access/librar_plugin.so
%{_libdir}/vlc/plugins/access/libsftp_plugin.so
%{_libdir}/vlc/plugins/access/libsmb_plugin.so
%{_libdir}/vlc/plugins/access/libtcp_plugin.so
%{_libdir}/vlc/plugins/access/libudp_plugin.so
%{_libdir}/vlc/plugins/access/libvdr_plugin.so
%{_libdir}/vlc/plugins/access/libdc1394_plugin.so
%{_libdir}/vlc/plugins/access/libdv1394_plugin.so

%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/access/libdvdnav_plugin.so
%{_libdir}/vlc/plugins/access/libdvdread_plugin.so
%endif

%{_libdir}/vlc/plugins/access/libfilesystem_plugin.so
%{_libdir}/vlc/plugins/access/libidummy_plugin.so

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/access/liblibbluray_plugin.so
%endif
%{_libdir}/vlc/plugins/access/liblive555_plugin.so
%{_libdir}/vlc/plugins/access/liblinsys_hdsdi_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/access/liblinsys_sdi_plugin.so
%endif

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/access/libpulsesrc_plugin.so
%if 0%{?suse_version} < 1330 && ( 0%{?sle_version} < 120200 || 0%{?is_opensuse} < 1 )
%{_libdir}/vlc/plugins/access/librdp_plugin.so
%endif
%endif
%{_libdir}/vlc/plugins/access/librtp_plugin.so
%{_libdir}/vlc/plugins/access/libsdp_plugin.so
%{_libdir}/vlc/plugins/access/libshm_plugin.so
%{_libdir}/vlc/plugins/access/libtimecode_plugin.so
%{_libdir}/vlc/plugins/access/libv4l2_plugin.so
%{_libdir}/vlc/plugins/access/libvcd_plugin.so
%{_libdir}/vlc/plugins/access/libvcdx_plugin.so

%if %{with vnc}
%{_libdir}/vlc/plugins/access/libvnc_plugin.so
%endif
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/access/libxcb_screen_plugin.so
%endif
%{_libdir}/vlc/plugins/access/libzip_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_dummy_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_file_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_http_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_livehttp_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_shout_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_udp_plugin.so
%{_libdir}/vlc/plugins/audio_filter/liba52tospdif_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libaudio_format_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libaudiobargraph_a_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libchorus_flanger_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libcompressor_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libdolby_surround_decoder_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libdtstospdif_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libequalizer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libgain_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libheadphone_channel_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libkaraoke_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libmono_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libnormvol_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libparam_eq_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libremap_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libsamplerate_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libscaletempo_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libsimple_channel_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libspatializer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libspeex_resampler_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libstereo_widen_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libtrivial_channel_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libugly_resampler_plugin.so
%{_libdir}/vlc/plugins/audio_mixer/libfloat_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_mixer/libinteger_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_output/libadummy_plugin.so
%{_libdir}/vlc/plugins/audio_output/libalsa_plugin.so
%{_libdir}/vlc/plugins/audio_output/libamem_plugin.so
%{_libdir}/vlc/plugins/audio_output/libafile_plugin.so
%{_libdir}/vlc/plugins/audio_output/libjack_plugin.so

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/audio_output/libpulse_plugin.so
%endif
%{_libdir}/vlc/plugins/codec/liba52_plugin.so
%{_libdir}/vlc/plugins/codec/libadpcm_plugin.so
%{_libdir}/vlc/plugins/codec/libaes3_plugin.so
%{_libdir}/vlc/plugins/codec/libaraw_plugin.so
%{_libdir}/vlc/plugins/codec/libavcodec_plugin.so
%{_libdir}/vlc/plugins/codec/libcc_plugin.so
%{_libdir}/vlc/plugins/codec/libcdg_plugin.so
%{_libdir}/vlc/plugins/codec/libcvdsub_plugin.so
%{_libdir}/vlc/plugins/codec/libddummy_plugin.so
%{_libdir}/vlc/plugins/demux/libdiracsys_plugin.so
%{_libdir}/vlc/plugins/codec/libdts_plugin.so
%{_libdir}/vlc/plugins/codec/libdvbsub_plugin.so
%{_libdir}/vlc/plugins/codec/libedummy_plugin.so
%{_libdir}/vlc/plugins/codec/libvpx_plugin.so
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/codec/libflac_plugin.so
%endif

%if %{with fluidsynth}
%{_libdir}/vlc/plugins/codec/libfluidsynth_plugin.so
%endif

%if 0%{?suse_version} > 1140
%if 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/codec/libhwdummy_plugin.so
%endif
%{_libdir}/vlc/plugins/codec/libjpeg_plugin.so
%endif
%{_libdir}/vlc/plugins/codec/libg711_plugin.so
%{_libdir}/vlc/plugins/codec/libkate_plugin.so
%{_libdir}/vlc/plugins/codec/liblpcm_plugin.so
%{_libdir}/vlc/plugins/codec/libmpeg_audio_plugin.so
%{_libdir}/vlc/plugins/codec/libopus_plugin.so
%{_libdir}/vlc/plugins/codec/libpng_plugin.so
%{_libdir}/vlc/plugins/codec/librawvideo_plugin.so
%{_libdir}/vlc/plugins/codec/libschroedinger_plugin.so
%{_libdir}/vlc/plugins/codec/libspeex_plugin.so
%{_libdir}/vlc/plugins/codec/libspudec_plugin.so
%{_libdir}/vlc/plugins/codec/libstl_plugin.so
%{_libdir}/vlc/plugins/codec/libscte27_plugin.so
%{_libdir}/vlc/plugins/codec/libsubsdec_plugin.so
%{_libdir}/vlc/plugins/codec/libsubstx3g_plugin.so
%{_libdir}/vlc/plugins/codec/libsubsusf_plugin.so
%{_libdir}/vlc/plugins/codec/libsvcdsub_plugin.so
%{_libdir}/vlc/plugins/codec/libt140_plugin.so
%{_libdir}/vlc/plugins/codec/libtelx_plugin.so
%{_libdir}/vlc/plugins/codec/libtheora_plugin.so
%{_libdir}/vlc/plugins/codec/libuleaddvaudio_plugin.so
%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/codec/libvaapi_drm_plugin.so
%endif
%{_libdir}/vlc/plugins/codec/libvaapi_x11_plugin.so
%{_libdir}/vlc/plugins/codec/libvorbis_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/codec/libxwd_plugin.so
%{_libdir}/vlc/plugins/codec/libzvbi_plugin.so
%endif

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/control/libdbus_plugin.so
%endif
%{_libdir}/vlc/plugins/control/libdummy_plugin.so
%{_libdir}/vlc/plugins/control/libgestures_plugin.so
%{_libdir}/vlc/plugins/control/libhotkeys_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/control/libxcb_hotkeys_plugin.so
%endif
%{_libdir}/vlc/plugins/control/liblirc_plugin.so
%{_libdir}/vlc/plugins/control/libmotion_plugin.so
%{_libdir}/vlc/plugins/control/libnetsync_plugin.so
%{_libdir}/vlc/plugins/control/liboldrc_plugin.so
%{_libdir}/vlc/plugins/demux/libaiff_plugin.so
%{_libdir}/vlc/plugins/demux/libasf_plugin.so
%{_libdir}/vlc/plugins/demux/libau_plugin.so
%{_libdir}/vlc/plugins/demux/libavformat_plugin.so
%{_libdir}/vlc/plugins/demux/libavi_plugin.so
%{_libdir}/vlc/plugins/demux/libcaf_plugin.so
%{_libdir}/vlc/plugins/demux/libdemux_cdg_plugin.so
%{_libdir}/vlc/plugins/demux/libdemux_stl_plugin.so
%{_libdir}/vlc/plugins/demux/libdemuxdump_plugin.so
%{_libdir}/vlc/plugins/demux/libes_plugin.so
%{_libdir}/vlc/plugins/demux/libflacsys_plugin.so
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/demux/libgme_plugin.so
%endif
%{_libdir}/vlc/plugins/demux/libh264_plugin.so
%{_libdir}/vlc/plugins/demux/libimage_plugin.so
%{_libdir}/vlc/plugins/demux/libmjpeg_plugin.so
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/demux/libmkv_plugin.so
%endif
%{_libdir}/vlc/plugins/demux/libmod_plugin.so
%{_libdir}/vlc/plugins/demux/libmp4_plugin.so
%{_libdir}/vlc/plugins/demux/libmpgv_plugin.so
%{_libdir}/vlc/plugins/demux/libnsc_plugin.so
%{_libdir}/vlc/plugins/demux/libnsv_plugin.so
%{_libdir}/vlc/plugins/demux/libnuv_plugin.so
%{_libdir}/vlc/plugins/demux/libogg_plugin.so
%{_libdir}/vlc/plugins/demux/libplaylist_plugin.so
%{_libdir}/vlc/plugins/demux/libps_plugin.so
%{_libdir}/vlc/plugins/demux/libpva_plugin.so
%{_libdir}/vlc/plugins/demux/librawaud_plugin.so
%{_libdir}/vlc/plugins/demux/librawdv_plugin.so
%{_libdir}/vlc/plugins/demux/librawvid_plugin.so
%{_libdir}/vlc/plugins/demux/libreal_plugin.so
%{_libdir}/vlc/plugins/demux/libsmf_plugin.so
%{_libdir}/vlc/plugins/demux/libsubtitle_plugin.so
%{_libdir}/vlc/plugins/demux/libts_plugin.so
%{_libdir}/vlc/plugins/demux/libtta_plugin.so
%{_libdir}/vlc/plugins/demux/libty_plugin.so
%{_libdir}/vlc/plugins/demux/libvc1_plugin.so
%{_libdir}/vlc/plugins/demux/libvobsub_plugin.so
%{_libdir}/vlc/plugins/demux/libvoc_plugin.so
%{_libdir}/vlc/plugins/demux/libwav_plugin.so
%{_libdir}/vlc/plugins/demux/libxa_plugin.so
%{_libdir}/vlc/plugins/gui/libskins2_plugin.so
%{_libdir}/vlc/plugins/lua/liblua_plugin.so

%if 0%{?suse_version} >= 1320
%{_libdir}/vlc/plugins/gui/libncurses_plugin.so
%endif
%{_libdir}/vlc/plugins/meta_engine/libfolder_plugin.so
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/meta_engine/libtaglib_plugin.so
%endif
%{_libdir}/vlc/plugins/misc/libaddonsfsstorage_plugin.so
%{_libdir}/vlc/plugins/misc/libaddonsvorepository_plugin.so
%{_libdir}/vlc/plugins/misc/libaudioscrobbler_plugin.so

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/misc/libdbus_screensaver_plugin.so
%endif
%{_libdir}/vlc/plugins/misc/libexport_plugin.so
%{_libdir}/vlc/plugins/misc/libfingerprinter_plugin.so

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/misc/libgnutls_plugin.so
%endif
%{_libdir}/vlc/plugins/misc/liblogger_plugin.so
%{_libdir}/vlc/plugins/misc/libstats_plugin.so
%{_libdir}/vlc/plugins/misc/libvod_rtsp_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/misc/libxdg_screensaver_plugin.so
%endif
%{_libdir}/vlc/plugins/misc/libxml_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_asf_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_avi_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_dummy_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_mp4_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_mpjpeg_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_ogg_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_ps_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_ts_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_wav_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_avparser_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_copy_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_dirac_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_flac_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_h264_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mlp_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mpeg4audio_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mpeg4video_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mpegvideo_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_vc1_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libbonjour_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libmediadirs_plugin.so
%if 0%{?suse_version} > 1110 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/services_discovery/libmtp_plugin.so
%endif
%{_libdir}/vlc/plugins/services_discovery/libpodcast_plugin.so

%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/services_discovery/libpulselist_plugin.so
%endif
%{_libdir}/vlc/plugins/services_discovery/libsap_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libudev_plugin.so
%if 0%{?suse_version} > 1110
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
%{_libdir}/vlc/plugins/services_discovery/libupnp_plugin.so
%endif
%endif
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/services_discovery/libxcb_apps_plugin.so
%endif
%{_libdir}/vlc/plugins/stream_filter/libdecomp_plugin.so
%{_libdir}/vlc/plugins/stream_filter/libdash_plugin.so
%{_libdir}/vlc/plugins/stream_filter/libhttplive_plugin.so
%{_libdir}/vlc/plugins/stream_filter/librecord_plugin.so
%{_libdir}/vlc/plugins/stream_filter/libsmooth_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_autodel_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_bridge_plugin.so

%if 0%{?suse_version} > 1140 && 0%{?suse_version} != 1315
%{_libdir}/vlc/plugins/stream_out/libstream_out_chromaprint_plugin.so
%endif
%{_libdir}/vlc/plugins/stream_out/libstream_out_delay_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_description_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_display_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_dummy_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_duplicate_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_es_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_gather_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_langfromtelx_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_mosaic_bridge_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_raop_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_record_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_rtp_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_setid_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_smem_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_standard_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_stats_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_transcode_plugin.so
%{_libdir}/vlc/plugins/text_renderer/libsvg_plugin.so
%{_libdir}/vlc/plugins/text_renderer/libtdummy_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libgrey_yuv_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_rgb_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_yuy2_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi422_i420_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi422_yuy2_plugin.so

%ifarch %ix86 x86_64
%if 0%{?suse_version} > 1140
%{_libdir}/vlc/plugins/video_chroma/libi420_rgb_mmx_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_rgb_sse2_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_yuy2_mmx_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_yuy2_sse2_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi422_yuy2_mmx_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi422_yuy2_sse2_plugin.so
%endif
%endif
%ifarch ppc ppc64 ppc64le
%{_libdir}/vlc/plugins/video_chroma/libi420_yuy2_altivec_plugin.so
%endif
%{_libdir}/vlc/plugins/video_chroma/librv32_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libyuy2_i420_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libyuy2_i422_plugin.so
%{_libdir}/vlc/plugins/video_filter/libadjust_plugin.so
%{_libdir}/vlc/plugins/video_filter/libalphamask_plugin.so
%{_libdir}/vlc/plugins/video_filter/libanaglyph_plugin.so
%{_libdir}/vlc/plugins/video_filter/libantiflicker_plugin.so
%{_libdir}/vlc/plugins/video_filter/libaudiobargraph_v_plugin.so
%{_libdir}/vlc/plugins/video_filter/libball_plugin.so
%{_libdir}/vlc/plugins/video_filter/libblend_plugin.so
%{_libdir}/vlc/plugins/video_filter/libblendbench_plugin.so
%{_libdir}/vlc/plugins/video_filter/libbluescreen_plugin.so
%{_libdir}/vlc/plugins/video_filter/libcanvas_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libchain_plugin.so
%{_libdir}/vlc/plugins/video_splitter/libclone_plugin.so
%{_libdir}/vlc/plugins/video_filter/libcolorthres_plugin.so
%{_libdir}/vlc/plugins/video_filter/libcroppadd_plugin.so
%{_libdir}/vlc/plugins/video_filter/libdeinterlace_plugin.so
%{_libdir}/vlc/plugins/video_filter/libdynamicoverlay_plugin.so
%{_libdir}/vlc/plugins/video_filter/liberase_plugin.so
%{_libdir}/vlc/plugins/video_filter/libextract_plugin.so
%{_libdir}/vlc/plugins/video_filter/libfreeze_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgaussianblur_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgradfun_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgradient_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgrain_plugin.so
%{_libdir}/vlc/plugins/video_filter/libhqdn3d_plugin.so
%{_libdir}/vlc/plugins/video_filter/libinvert_plugin.so
%{_libdir}/vlc/plugins/video_filter/liblogo_plugin.so
%{_libdir}/vlc/plugins/video_filter/liboldmovie_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmagnify_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmarq_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmirror_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmosaic_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmotionblur_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmotiondetect_plugin.so
%if 0%{?suse_version} > 1110
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
%{_libdir}/vlc/plugins/video_filter/libopencv_example_plugin.so
%{_libdir}/vlc/plugins/video_filter/libopencv_wrapper_plugin.so
%endif
%endif
%{_libdir}/vlc/plugins/video_filter/libposterize_plugin.so
%{_libdir}/vlc/plugins/video_filter/libpsychedelic_plugin.so
%{_libdir}/vlc/plugins/video_filter/libpuzzle_plugin.so
%{_libdir}/vlc/plugins/video_filter/libripple_plugin.so
%{_libdir}/vlc/plugins/video_filter/librotate_plugin.so
%{_libdir}/vlc/plugins/video_filter/librss_plugin.so
%{_libdir}/vlc/plugins/video_filter/libscale_plugin.so
%{_libdir}/vlc/plugins/video_filter/libscene_plugin.so
%{_libdir}/vlc/plugins/video_filter/libsepia_plugin.so
%{_libdir}/vlc/plugins/video_filter/libsharpen_plugin.so
%{_libdir}/vlc/plugins/video_filter/libsubsdelay_plugin.so
%if 0%{?suse_version} >= 1140 && 0%{?suse_version} != 1315 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/video_chroma/libswscale_plugin.so
%endif
%{_libdir}/vlc/plugins/video_filter/libtransform_plugin.so
%{_libdir}/vlc/plugins/video_filter/libvhs_plugin.so
%{_libdir}/vlc/plugins/video_splitter/libwall_plugin.so
%{_libdir}/vlc/plugins/video_filter/libwave_plugin.so
%{_libdir}/vlc/plugins/video_filter/libyuvp_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/video_output/libcaca_plugin.so
%endif
%{_libdir}/vlc/plugins/video_output/libfb_plugin.so
%{_libdir}/vlc/plugins/video_output/libgl_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/video_output/libglx_plugin.so
%endif
%{_libdir}/vlc/plugins/video_output/libvdummy_plugin.so
%{_libdir}/vlc/plugins/video_output/libvmem_plugin.so
%{_libdir}/vlc/plugins/video_output/libvout_sdl_plugin.so
%if 0%{?suse_version} > 1110
%{_libdir}/vlc/plugins/video_output/libxcb_window_plugin.so
%{_libdir}/vlc/plugins/video_output/libxcb_x11_plugin.so
%{_libdir}/vlc/plugins/video_output/libxcb_xv_plugin.so
%endif
%{_libdir}/vlc/plugins/video_output/libyuv_plugin.so
%{_libdir}/vlc/plugins/visualization/libvisual_plugin.so

%if %{with gstreamer}
%files codec-gstreamer
%defattr(-,root,root)
%{_libdir}/vlc/plugins/codec/libgstdecode_plugin.so
%endif

%if 0%{?BUILD_ORIG}
%files codecs
%defattr(-,root,root)
%{_libdir}/vlc/plugins/audio_filter/liba52tofloat32_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libdtstofloat32_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libmpgatofixed32_plugin.so
%{_libdir}/vlc/plugins/codec/libfaad_plugin.so
%{_libdir}/vlc/plugins/codec/liblibmpeg2_plugin.so
%{_libdir}/vlc/plugins/codec/libtwolame_plugin.so
%{_libdir}/vlc/plugins/codec/libx264_plugin.so
#{_libdir}/vlc/plugins/codec/libx265_plugin.so
%if 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/demux/libhevc_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_hevc_plugin.so
%endif
%if 0%{?suse_version} > 1140
%{_libdir}/vlc/libvlc_vdpau.so.0
%{_libdir}/vlc/libvlc_vdpau.so.0.0.0
%dir %{_libdir}/vlc/plugins/vdpau
%{_libdir}/vlc/plugins/vdpau/libvdpau_adjust_plugin.so
%{_libdir}/vlc/plugins/vdpau/libvdpau_avcodec_plugin.so
%{_libdir}/vlc/plugins/vdpau/libvdpau_chroma_plugin.so
%{_libdir}/vlc/plugins/vdpau/libvdpau_deinterlace_plugin.so
%{_libdir}/vlc/plugins/vdpau/libvdpau_display_plugin.so
%{_libdir}/vlc/plugins/vdpau/libvdpau_sharpen_plugin.so
%endif
%{_libdir}/vlc/plugins/video_filter/libpostproc_plugin.so
%endif

%files -n libvlc%{libvlc}
%defattr(-,root,root)
%{_libdir}/libvlc.so.%{libvlc}*

%files -n libvlccore%{libvlccore}
%defattr(-,root,root)
%{_libdir}/libvlccore.so.%{libvlccore}*

%files qt
%defattr(-,root,root)
%{_bindir}/qvlc
%{_mandir}/man1/qvlc*
%{_libdir}/vlc/plugins/gui/libqt4_plugin.so

%files devel
%defattr(-,root,root)
%{_includedir}/vlc/
%{_libdir}/libvlccore.so
%{_libdir}/libvlc.so
%{_libdir}/pkgconfig/libvlc.pc
%{_libdir}/pkgconfig/vlc-plugin.pc
%{_libdir}/vlc/libcompat.a
%if 0%{?BUILD_ORIG}
%if 0%{?suse_version} > 1140
%{_libdir}/vlc/libvlc_vdpau.so
%endif
%endif

%changelog
* Thu Sep 21 2017 dimstar@opensuse.org
- Add vlc-flac-heap-overflow.patch: flac: fix heap write overflow
  on frame format change (CVE-2017-9300, boo#1041907).
* Tue Sep 19 2017 dimstar@opensuse.org
- Stop depending on libkde4-devel: It's only used to find the
  install path for kde4, but configure falls back to the correct
  default for openSUSE anyway (boo#1057736).
* Fri Aug 11 2017 aloisio@gmx.com
- Added vlc-projectM-qt5.patch and applied it for Factory
* Mon Jul 24 2017 olaf@aepfle.de
- Adjust to API change in a52dec with vlc.a52.patch
* Thu Jun 22 2017 dimstar@opensuse.org
- Disable vnc access module: it does not work in my current tests.
* Fri May 26 2017 dimstar@opensuse.org
- Update to version 2.2.6:
  + Video output:
  - Fix systematic green line on nvidia.
  - Fix direct3d SPU texture offsets handling.
  + Demuxer: Fix heap buffer overflows.
- Changes from version 2.2.5.1:
  + Security hardening for DLL hijacking environments.
- Changes from version 2.2.5:
  + Decoder:
  - Fix mp3 playback quality regression in libmad.
  - Fix video scaling in VDPAU.
  - Fix playback of palettized codecs.
  - Fix ADPCM heap corruption (FG-VD-16-067).
  - Fix AES3 16bps decoding.
  - Fix DVD/LPCM heap corruption (FG-VD-16-090).
  - Fix SCTE-27 colors.
  + Demuxer:
  - Fix possible ASF integer overflow.
  - Fix MP4, VOC, XA, SMF divide-by-zero errors.
  - Fix MP4 heap buffer overflows.
  - Fix Flac metadata integer overflow.
  - Fix NSVf and AIFF infinite loops.
  - Fix flac null-pointer dereference.
  - Fix vorbis and opus comments integer overflows and leaks.
  + Video output:
  - Fix green line on Windows with AMD drivers.
  - Fix screenshots size.
  + Access:
  - Fix crash in screen recording on Windows.
  - Fix FTP scan string injection.
  - Fix HTTP size handling.
  + Mux: Fix mp4 drift.
  + Lua: Fix vimeo, youtube, dailymotion, cli, appletrailers, http,
    soundcloud scripts.
  + Audio filter: Fix heap write in stereo_widen audio filter.
- Rebase 0001-no-return-in-non-void.patch.
- Drop vlc-2.1.5-fix-skins2-default-skin-creation.patch: this
  should really not be required anymore.
* Wed May  3 2017 dimstar@opensuse.org
- Replace libmodplug-devel BuildRequires with
  pkgconfig(libmodplug): this helps with the migration from
  libmodplug to openmpt.
* Tue Nov 29 2016 dimstar@opensuse.org
- Expand the lang_package macro in order to change the dependency
  to be on vlc-noX instead of vlc. USers of headless installed
  vlc might still be interested in translations too (boo#1012556).
* Wed Sep 28 2016 dimstar@opensuse.org
- Require libavcodec<ABI>(unrestricted) (<ABI> is automatically
  discovered during build based on what libavcodec.so links to)
  from vlc-codecs. This ensures that users installing vlc-codecs
  will get a prompt to replace the distro-provided libavcodec
  package - which is restricted in its formats. This requires the
  user to accept a vendor change.
* Tue Sep 20 2016 jengelh@inai.de
- Drop VLC from summaries (rpmlint: name-repeated-in-summary).
  Improve summaries and descriptions.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update summaries: 'VLC' is sufficiently known by now - and nobody
  really remembers the name 'Video Lan Client'.
* Fri Sep 16 2016 dimstar@opensuse.org
- Rename vlc-noX-lang to vlc-lang: this helps the AppStream builder
  in confirming that 'vlc' (the application) does have a full
  translation set. Obsolete vlc-noX-lang by vlc-noX directly.
* Mon Sep  5 2016 dimstar@opensuse.org
- Drop vlc-2.2.4-unambig-shortcuts.patch: it does not solve the
  problem it attempted to solve to start with. A better solution
  is to be found with upstream.
* Sun Sep  4 2016 dimstar@opensuse.org
- Update vlc-2.2.4-unambig-shortcuts.patch: Also make ALT-P
  unambiguous.
* Wed Aug 31 2016 dimstar@opensuse.org
- Also use ffmpeg2-devel BuildRequires on Leap 42.2 (sle_version
  120200).
* Mon Aug 22 2016 dimstar@opensuse.org
- Add ffmpeg2-devel BuildRequires for Tumbleweed: older openSUSE
  versions had ffmpeg 2.x in the distribution.
* Wed Aug 10 2016 dimstar@opensuse.org
- BuildConflict pkgconfig(libavutil) >=55: vlc 2.2.x is not yet
  compatible with these updates.
* Tue Aug  9 2016 dimstar@opensuse.org
- Enable avcodec on openSUSE since ffmpeg had been in the distro
  since Leap 42.1.
* Thu Aug  4 2016 dimstar@opensuse.org
- Build GStreamer plugin support:
  + Add pkgconfig(gstreamer-app-1.0) BuildRequires.
  + Split out new package vlc-codec-gstreamer, which is triggered
    for automatic installation if vlc-noX and libgstapp are present
    on the system. By using the GStreamer extension one can make
    use of all available addons there (incl. OnePlay codec packs).
* Thu Aug  4 2016 dimstar@opensuse.org
- Add vlc-2.2.4-unambig-shortcuts.patch: Make keyboard shortcuts
  in open dialog unambiguous.
* Wed Aug  3 2016 badshah400@gmail.com
- Add and install appdata file.
* Sun Jul 10 2016 suse@tleine.de
- disable freerdp module support on openSUSE Leap 42.2. It
  has freerdp 2.
* Thu Jun 23 2016 meissner@suse.com
- build binaries as PIE (position independend executable).
* Mon Jun 13 2016 dimstar@opensuse.org
- Update to version 2.2.4:
  + Decoder:
  - Fix crash in G.711 wav files.
  - Fix mp3 crash in libmad.
  - Fix out-of-bound write in adpcm QT IMA codec (CVE-2016-5108,
    boo#984382).
  + Qt: Fix resizing issues.
  + Win32: Fix overlay creation on Windows XP for DirectDraw video
    output.
  + Misc: Build fixes for Hurd.
  + Updated translations.
* Tue May 24 2016 dimstar@opensuse.org
- Add vlc-gcc6-buildfixes.patch: fix build with GCC 6. This patch
  file is a collection of the backported commits from master:
  + 5d26efcad8d1aa5023028e3caa5a608b5e1d81fe
  + 406f697d5592752efc8a0479e48512ed20ab274b
  + 569df08d1be561022b86ce9c58dece388532e818
  + 45495aa458ef6856ee9eb18860706149148bb660
  + a7a70e8163e04244d733f4745dc8cbbc7502b830
  + ada4b4748eefcfd22f1417ed223f1381c694aa60
  + 0bcb7fd2567ba494b730234609b146cd8e23483c
  + 59678ec0b489d86f6f62cc987e21a82346f8da42
  + e8b683357b2ccc2bbd1ffbcb4783441a3620a6ea
  + ab550d60dd8d823b8ddacd2d4759f0840a9ea352
  + f5d5cb75768b692359068e837f72c9fd7cf6bd45
  + c5f80f5bc4cb498c8eb7469650437e92ae6d085a
  + 66842e08e177e3c458fa0e4db970deae84feb625
  + 98b4e987252f798213effa5ed6d19d958d6d9d42
  + d2571e643edb0f1cb217805ef8d5ac172d59a864
- Disable atmoLight sensor: pass --disable-atmo to configure. This
  module fails to build with GCC 6 and has been removed upstream
  for the next version of VLC already (671304).
* Mon May 23 2016 dimstar@opensuse.org
- Disable freerdp module support on openSUSE Tumbleweed: VLC has
  not been ported to FreeRDP 2.0.
* Tue May  3 2016 dimstar@opensuse.org
- Update to version 2.2.3:
  + Demux:
  - Fix HLS quality selection and a potential stack overflow.
  - Fix potential MKV infinite loop and improve MKV tags support.
  - Fix WMV regression.
  + Decoder:
  - Fix hardware decoding with libvdpau-va-gl.
  - Fix crashes with libvpx.
  - Use libass without caching dialog.
  + Video Ouptut: Fix green lines on Direct3D output.
  + Skins2: Fix maximizing Window in multi-screen context.
  + Qt:
  - Fix resume where you left off.
  - Fix infinite recursion in the customize dialog.
  - Fix size when switching to/from the minimal interface.
  - Fix size after resume toolbar is displayed.
  + MacOS X:
  - Fix crashes in media information panel.
  - Correctly respect the disable-screensaver option.
  + Win32: Allow opening more than 15 elements in Explorer.
  + Updated translations.
* Wed Mar 16 2016 dimstar@opensuse.org
- Disable deprecated gnome-vfs2 support (that was GNOME 2 tech):
  + Replace --enable-gnomevfs configure parameter with
  - -disable-gnomevfs.
  + Remove gnome-vfs2-devel BuildRequires.
  + Drop -gnome subpackage and obsolete it by the main package.
* Fri Feb  5 2016 dimstar@opensuse.org
- Update to version 2.2.2:
  + libVLC:
  - Expose audio mute, cork and volume change events:
    libvlc_MediaPlayerCorked, libvlc_MediaPlayerUncorked,
    libvlc_MediaPlayerMuted, libvlc_MediaPlayerUnmuted and
    libvlc_MediaPlayerAudioVolume.
  - Fix propagation of libvlc_MediaPlayerTitleChanged event.
  + Access:
  - Fix SetupFormat for continuous framesize in v4l2.
  - Fix off-by-one buffer overflow in RealRtsp module.
  - Fix screen recording aspect-ratio, framerate and potential
    crash.
  - Fix Windows directshow input freeze.
  - Fix MMS segmentation fault/abort when server forces a large
    allocation.
  + Demux:
  - Fix support for ms-dvr files.
  - Fix time detection in AVI files over HTTP.
  - HLS: fix hang on stop, crashes and small improvements.
  - Fix mp4 NULL dereference reported by by Fortinet's FortiGuard
    Labs.
  - Fix regression for VC-1 in WMV.
  - Fix MXF crashes on stop.
  - Fix EAC3 detection in some TS files.
  + Decoders:
  - Fix importing surface from main memory in VDPAU.
  - Fix possible double-free in ADPCM decoder.
  - Support 9-bit and 10-bit GBR planar formats.
  - Support GoToMeeting 2 and GoToMeeting 3 codecs.
  - Fix crash in teletext (zvbi) decoder.
  - Fix Bluray subtitles (PGS) timestamps.
  + Audio output:
  - Fix audio drop after a flush with pulseaudio.
  - Fix audio initialization on iOS.
  - Fix audio stuttering with AirPlay devices on OS X (2 sec
    delay needs to be set manually by the user).
  - Fix pulseaudio latency computation.
  - Fix alsa default device selection.
  + Skins2:
  - Fix video control that fails to show up.
  - Fix UTF-8 conversion issues.
  - Fix Unicode folders location failing to open the skins.
  - Fix crash over malformed skins bitmaps.
  - Fix fullscreen for Gnome3/Unity Window Managers.
  + OS X fixes.
  + Qt:
  - Fix crash when opening multiple items on Windows.
  - Fix recent items appending when using a playlist.
  - Improve addons manager dialog, playlist.
  - Fix changing the audio-device in the menu.
  - Fix key and mouse event support for Qt >= 5.5 under X11.
  - Fix memory leaks.
  + Video Output:
  - Fix build if one disables XCB but activate VDPAU on Unix.
  - Fix Direct3D plane allocation size to avoid colour bleeding.
  - Fix some crashes in swscale resizing.
  + Misc:
  - Fix build with recent FreeRDP versions.
  - Fix interface crashes when input-title-format option is
    empty.
  - Fix MP4 mux divide-by-zero crash.
  - Improve PNG encoding time.
  - Fix some UPnP initialization lag.
  - Rewrite of the Jamendo Service Discovery.
  - Fix snapshot aspect ratio for anamorphic contents.
  - Fix custom snapshot sizes.
  - Dynamic generation of GnuTLS Diffie-Hellman parameters.
  - Fix "vb" transcoding parameter.
  - Fix superfluous audio channel extraction in the core.
  - Fix miscellaneous crashes, double-frees, integer overflows,
    infinite loops, read overflow, invalid frees and division by
    zero issues.
  - Fix support for lua 5.2 and fix XSS in the http interface.
  - Update and improve Soundcloud, Vimeo and Youtube scripts.
  - Update of codecs and libraries to fix 3rd party security
    issues (like TALOS-CAN-0036, TALOS-CAN-0037, CVE-2015-7981,
    CVE-2015-8126).
  + Updated translations.
- Drop vlc-CVE-2015-5949.patch and vlc-qt5.5-mousepointer.patch:
  fixed upstream.
- Add vlc-support-qt5.5.patch (reverse applied): The Qt 5.5 package
  in Leap and Tumbleweed have been patched to have the fix upstream
  wanted to make us aware of with this commit.
* Fri Feb  5 2016 dimstar@opensuse.org
- Add vlc-CVE-2015-5949.patch: demux: mp4: correctly match release
  function (boo#965227, CVE-2015-5949).
* Mon Jan  4 2016 ctrippe@opensuse.org
- Install the solid action desktop files also in /usr/share/solid/actions
  to make them available in Plasma5 (boo#960621)
* Mon Dec 28 2015 wbauer@tmo.at
- Build against libQt5X11Extras5 on Leap as well to make video
  integration into the GUI work (boo#953693)
- Also add BuildRequires: pkgconfig(xi), without it the build fails
  on Leap now
* Tue Dec 15 2015 dimstar@opensuse.org
- Enable libupnp support on Leap 42.1: the library is available
  (boo#959100).
* Mon Dec  7 2015 dimstar@opensuse.org
- Add vlc-qt5.5-mousepointer.patch: Fix mouse cursor in video
  interface (boo#956769).
* Tue Dec  1 2015 lnussel@suse.de
- libvlc_vdpau needs to be in codecs package to avoid dependency issue
* Sun Nov 22 2015 jdelvare@suse.com
- Don't pass --enable-dca unconditionally, it is handled later with
  a condition.
* Wed Sep  2 2015 wbauer@tmo.at
- Modify vlc-2.1.5-fix-skins2-default-skin-creation.patch to patch
  Makefile.am instead of Makefile.in: autoreconf overwrote the
  change, making the patch totally ineffective and thus the default
  skin was broken
* Fri Jul 24 2015 dimstar@opensuse.org
- Fix build with LUA 5.3 / 5.3.1.
* Fri May 15 2015 joerg.lorenzen@ki.tng.de
- Enabled VPX support.
* Wed May 13 2015 aloisio@gmx.com
- Enabled Qt5 for targets that support it.
* Fri May  1 2015 jengelh@inai.de
- Enable ffmpeg for newer openSUSE
* Tue Apr 28 2015 tittiatcoke@gmail.com
- Regenerate the cache for all packages that install plugins.
  This otherwise would cause issues during the switch from Qt4-Qt5
* Fri Apr 24 2015 joerg.lorenzen@ki.tng.de
- Build against qt5 for openSUSE > 13.2.
* Tue Apr 21 2015 seife+obs@b1-systems.com
- remove build host name (again) from binaries
* Tue Apr 14 2015 aloisio@gmx.com
- Removed DTV/DVB patch that was fixed upstream.
* Mon Apr 13 2015 joerg.lorenzen@ki.tng.de
- Update to version 2.2.1:
  + Codec:
  - Fix compilation with older libavcodec versions.
  - Fix some VP9 decoding.
  - Fix flac crashes.
  - Fix lpcm channel ordering.
  - Fix potential NULL dereference in dmo.
  - Fix teletext framing code in DVB PES packets.
  - Fix potential buffer overflow in schroendinger decoder.
  - Fix AAC samplerate.
  + Demuxers:
  - Fix MP4 chapters.
  - Fix MKV overseeking, introducing slowness over network shares.
  - Fix crash when playing SPC files.
  - Fix ATRAC3 playback in MKV.
  - Revert to older ASX code.
  - Workaround TS issue with mpeg-audio.
  + Access:
  - Fix sftp read and close sockets.
  - Fix DTV build with Linux DVB versions < 5.8.
  - Fix UDP/RTP input on Windows.
  + Audio output:
  - Fix Alsa HDMI plugs.
  - Improve Alsa output, with larger buffers.
  - Fix DirectSound output with multi-channel files.
  + OS X:
  - Fix numerous crashes in the UI.
  - Fix video-wallpaper mode.
  - Fix race when starting VLC from command line.
  + Qt:
  - Fix recent items behaviour.
  - Fix rotation filter activation.
  - Fix mux modules names for the streaming wizard.
  + Win32:
  - Timestamp the signature of the dlls.
  - Fix extensions registration during install.
  - Fix extensions dialog crash.
  - Default to no DxVA decoding.
  + libVLC:
  - fix libvlc_media_get_stats.
  + Updated translations.
- Fixed patch 0001-no-return-in-non-void.patch.
* Sun Apr 12 2015 dimstar@opensuse.org
- Require at least the version of libbluray1 that was used during
  build. libbluray.so.1 has a strange ABI diff between 0.3 and 0.7.
  Libbluray had an API/ABI break at 0.5, which was not represented
  in a soname bump (boo#926842).
* Tue Mar 31 2015 dvlaeev@suse.com
- Fix package lists for PowerPC architectures.
* Tue Mar 17 2015 dimstar@opensuse.org
- Move vlc.desktop vlc package: AppStream bases the addition of
  packages to the store based on the .desktop file (which
  identifies the application). In case of VLC, we want to present
  'the full set' as part of the App Stores.
* Wed Mar  4 2015 dimstar@opensuse.org
- Reintroduce calling {_libdir}/vlc/vlc-cache-gen during post.
* Tue Mar  3 2015 aloisio@gmx.com
- made fludsynth optional again out of caution
- added vlc-2.2.0-fix_deinterlace_mmx.patch to make
  SLE11/i586 build without a recent enough gcc
- fixed SLE11 to build without automake >= 1.11
- fixed a SLE12 build problem on packman
- removed hevc plugins in a cleaner way
* Sun Mar  1 2015 aloisio@gmx.com
- enabled ncurses for Factory
- enabled fluidsynth unconditionally
- enabled libcdio
- enabled x265 for packman
- fixed SLE11/SLE12 build
- added vlc-rpmlintrc to suppress bogus warnings
- added manpages for the various versions of vlc
  as link to the main one
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 2.2.0:
  + Long awaited update with a huge changelog. Please see the
    content of /usr/share/doc/packages/vlc/NEWS.
- Drop vlc-CVE-2014-9625.patch: fixed upstream.
* Wed Feb  4 2015 dimstar@opensuse.org
- Add vlc.changes as source so that we can reliably access it
  during build, even when using the .src.rpm.
* Thu Jan 22 2015 dimstar@opensuse.org
- Add vlc-CVE-2014-9625.patch: Fix various buffer overflows and
  null ptr dereferencing (boo#914268, CVE-2014-9625).
* Sun Nov  9 2014 seife+obs@b1-systems.com
- fix skins2 defaut.vlt generation with newer tar defaults (and
  remove the embedded build date from it on the way)
  vlc-2.1.5-fix-skins2-default-skin-creation.patch
- remove buildhost hostname from the binary to avoid republishing
* Thu Oct 30 2014 olaf@aepfle.de
- Convert BuildRequires from foo-devel to pkgconfig(foo)
* Fri Oct 24 2014 dimstar@opensuse.org
- First attempts on enabling build for SLE-12.
* Thu Oct  9 2014 vindex17@outlook.it
- Enable SSE2 instruction set for x86_64
* Tue Oct  7 2014 dimstar@opensuse.org
- Disable fluidsynth again: the crashes we had earlier are still
  not all fixed. They are less, but less common makes it more
  difficult to debug.
* Sun Oct  5 2014 olaf@aepfle.de
- Enable build for SLE_11
* Tue Sep 23 2014 vindex17@outlook.it
- Fix rpmlint warning about duplicates with fdupes
- Add missing BuildRequires:
  + fluidsynth-devel: SMF files playback
  + freerdp-devel: RDP support
  + libkde4-devel: KDE integration
  + libchromaprint-devel: Chromaprint stream output
  + libmlt6-modules: television broadcasting
  + LibVNCServer-devel: VNC support
  + opencv-devel: real-time computer vision support
  + xcb-util-keysyms-devel: better X integration
- Remome gcc-c++ and libqt4-devel because automatically installed
- Add 'suse_version' conditionals to the new BuildRequires
- Remove 'suse_version' conditionals from live555-devel & lua-devel
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 2.1.5:
  + Core: Fix compilation on OS/2.
  + Access: Stability improvements for the QTSound capture module.
  + Mac OS X audio output:
  - Fix channel ordering.
  - Increase the buffersize.
  + Decoders:
  - Fix DxVA2 decoding of samples needing more surfaces.
  - Improve MAD resistance to broken mp3 streams.
  - Fix PGS alignment in MKV.
  + Qt Interface: Don't rename mp3 converted files to .raw.
  + Mac OS X Interface:
  - Correctly support video-on-top.
  - Fix video output event propagation on Macs with retina
    displays.
  - Stability improvements when using future VLC releases side by
    side.
  + Streaming: Fix transcode when audio format changes.
  + Updated translations.
* Thu May 15 2014 olaf@aepfle.de
- Include also libglobalhotkeys_plugin.so which is build with old x11
* Thu May 15 2014 olaf@aepfle.de
- BuildRequire at least gnutls 3.0.20
* Fri May  2 2014 olaf@aepfle.de
- BuildRequire at least jack 1.9.7
* Thu Apr 24 2014 olaf@aepfle.de
- BuildRequire libtag-devel instead of taglib-devel to work around
  a resolver bug. A package name from external project is prefered
  over a provide from the same project.
* Tue Apr 15 2014 olaf@aepfle.de
- Require plain lua-devel instead of lua51-devel for 12.1 or older
* Sat Mar  8 2014 dap.darkness@gmail.com
- Fixed PowerPC builds.
* Sun Feb 23 2014 dimstar@opensuse.org
- Update to version 2.1.4:
  + Demuxers: Fix issue in WMV with multiple compressed payload and
    empty payloads.
  + Video Output: Fix subtitles size rendering on Windows.
  + Mac OS X:
  - Fix DVD playback regression.
  - Fix misleading error message during video playback on
    OS X 10.9.
  - Fix hardware acceleration memleaks.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 2.1.3 (bnc#864422):
  + Core:
  - Fix broken behaviour with SOCKSv5 proxies
  - Fix integer overflow on error when using vlc_readdir
  + Access:
  - Fix DVB-T2 tuning on Linux.
  - Fix encrypted DVD playback.
  - Fix v4l2 frequency conversion.
  + Decoders:
  - Fix numerous issues (M2TS, VC1 interlaced, Lagarith, FFv1.3,
    Xvid) by updating codec libraries.
  - Bring fluidsynth back on Mac OS X
  - Fix some Opus crashes with some filters
  - Fix teletext crash on Windows
  + Demuxers:
  - Avoid an infinite recursion in MKV tags parsing
  - Fix an issue with some Vobsub tracks
  - Fix missing samples at the end of some wav files
  - Fix divide by 0 on ASF/WMV parsing
  + Audio output:
  - Fix audio device selection via command line on Mac OS X
  - Fix audio crashes on Mac OS X
  + Video Output:
  - Fix selection of DirectDraw as the default output for XP
  - Fix transform off-by-one issue
  - Fix screensaver disabling on Windows outputs
  - Fix DirectDraw device enumeration and multi-display output
  - Fix a potential crash when playing a fullscreen game at the same time as VLC
  + Stream output:
  - Fix 24bits audio MTU alignment in RTP
  - Fix record file names
  + Qt interface:
  - Fix minimal size possible on start
  - Fix a crash with the simple volume widget
  - Fix a crash in the audio menu building
  - Fix multimedia keys issues on Windows
  - Fix opening of DVD and BD folders on Windows
  + HTTP interface: Fix album art display on Windows.
  + Updated translations.
* Fri Dec 27 2013 claudiozumbo@gmail.com
- Add update-desktop-files BuildRequires and
  %%desktop_database_post/postun calls to respective scriptlets: Fix
  https://bugs.links2linux.org/browse/PM-108.
* Wed Dec 11 2013 dimstar@opensuse.org
- Update to version 2.1.2:
  + Audio output:
  - Fix digital playback on OS X when more than one audio device
    is installed.
  - Fix digital playback (SPDIF/HDMI) on Windows.
  - Fix stuttering or silent playback when using sound enhancers
    or external audio devices on OS X.
  - Improve responsiveness on OS X when playback starts or is
    being paused.
  - Improve responsiveness, silent playback intervals and
    reliability on iOS.
  + Demuxers:
  - Fix Vimeo and DailyMotion parsing.
  - Various WMV playback improvements and fixes.
  + Decoders:
  - Fix LPCM 20/24-bit decoding and 16 bits with channel padding.
  - Fix playback of some HEVC samples.
  + Video filters: Fix crash on deinterlace selection.
  + Qt interface:
  - Fix some streaming profiles when copy existed.
  - Improve A-B loop control.
  - Fix album art update when changing media.
  + Mac OS X interface adjustments.
  + Win32 installer: Kill running VLC process on uninstall/update.
  + Updated translations.
* Sat Nov 23 2013 dimstar@opensuse.org
- More features (by adding BuildRequires):
  + IDN Support (International Domain Names): libidn-devel
  + SFTP Access: libssh2-devel
  + HotKey Support: xcb-util-keysyms-devel
  + Complete SDL Stack: SDL_image-devel
  + ProjectM suppor (for openSUSE >= 12.3)
* Mon Nov 18 2013 dimstar@opensuse.org
- Update to version 2.1.1:
  + Core:
  - Fix random and reshuffling behaviour.
  - Fix recording.
  - Fix some subtitles track selection.
  + Decoders:
  - VP9 support in WebM.
  - HEVC/H.265 support in MKV, MP4 and raw files.
  - Fix GPU decoding under Windows (DxVA2) crashes.
  + Demuxers:
  - Fix crashes on wav, mlp and mkv and modplug files.
  - Support Speex in ogg files.
  - Fix some .mov playlists support.
  - Support Alac in mkv.
  - Fix WMV3 and palette in AVI.
  - Fix FLAC packetizer issues in some files.
  + Access:
  - Fix DVB options parsing.
  - Fix DeckLink HDMI input.
  - Fix HTTPS connectivity on OS X by loading root certificates
    from Keychain.
  + Audio output:
  - Fixes for DirectSound pass-through.
  - Fixes for OSS output, notably on BSD.
  + Interfaces:
  - Fix HTTP interface infinite loop.
  - Fix D-Bus volume setting.
  + Qt:
  - Reinstore right click subtitle menu to open a subtitle.
  - Fix saving the hotkeys in preferences.
  - Fix saving the audio volume on Win32, using DirectSound.
  - Fix play after drag'n drop.
  - Fix streaming options edition and scale parameter.
  + Stream out:
  - Fix transcoding audio drift issues.
  - Fix numerous audio encoding issues.
  + Win32 installer:
  - Important rewrite to fix numerous bugs, notably about
    updates.
  - Simplification of the upgrade mechanism.
  + Mac OS X interface:
  - Reintroduce the language selector known from pre-2.1
    releases.
  - Fix fullscreen behaviour and various crashes.
  - Fix about dialog crash in Japanese.
  - Fix crashes on proxy lookups.
  - Fixes on the playlist and information behaviours.
  - Fixes on the streaming dialogs.
  - Improves interface resizings.
  + Updated translations.
- Pass --with-default-font=[path] and
  - -with-default-monospace-font=[path] to configure.
- Drop fix_font_path.patch: replaced with configure parameters
  above.
* Wed Nov 13 2013 dimstar@opensuse.org
- Recommend 'vlc' by vlc-qt: some users might go installing the UI
  package directly. Having Qt most likely also means the user has X,
  so we at least recommend the vlc package relying on X.
* Thu Nov  7 2013 hrvoje.senjan@gmail.com
- Force creation of plugins cache in vlc-nox %%post, instead of just
  touching the file, for details see
  https://trac.videolan.org/vlc/ticket/9807#comment:2
* Thu Oct 24 2013 dimstar@opensuse.org
- Update License: A lot has been relicensed to LGPL-2.1.
* Mon Oct 21 2013 hrvoje.senjan@gmail.com
- Make vlc build on OBS for openSUSE 12.3 - BuildRequire
  pkgconfig(libswscale) and live555-devel on >= 13.1, and on
  BUILD_ORIG case
* Sat Oct 12 2013 scarabeus@opensuse.org
- Drop support for < 12.2 as it does not build anyway
  * Removal of pulseaudio subpackage and incorporating it to the
    noX package.
  * Cleanup of the dependencies and configure switches we don't
    need to use anymore.
- Add lang subpackage as it was most of what was noX package
  containing. This way we can reduce the size and use noarch there.
- Touch the ghosted file in %%post to make rpmlint happy
- Fix __DATE__ and __TIME__ usage so we do not rebuild so often.
- Drop obsolete configure options which are no longer around
- Disable xcb switch as we no longer build for such old distros.
* Wed Oct  2 2013 wbauer@tmo.at
- Re-add and adapt 0001-no-return-in-non-void.patch: fixes build on
  openSUSE versions other than Factory
* Wed Oct  2 2013 guillaume@opensuse.org
- Add support to openGL ES 2 (enabled by default for %%arm):
  + Introduce bcon_with(out) opengles.
  + If enabled, pass --enable-gles2 --enable-egl to configure.
  + Adjust the files section for that.
* Wed Oct  2 2013 guillaume@opensuse.org
- Add vdpau support to -codecs package (BUILD_ORIG):
  + BuildRequire libvdpua-devel
  + Adapt files section.
* Tue Oct  1 2013 dimstar@opensuse.org
- Only enable GME support on openSUSE >= 12.00 (disable on SLE11).
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 2.1.0:
  + Important changes:
  - The licenses of numerous modules have changed from GPLv2+ to
    LGPLv2.1+.
  - Discontinued support for PowerPC-based Macs; VLC now requires
    Mac OS X 10.6+.
  - The --with-tuning and --without-tuning options are removed;
    to tune compilation for a specific processor type, set CFLAGS
    manually.
  + LOTS of updates all over. See NEWS for a full overview.
- Rebase fix_font_path.patch.
- Drop 0001-no-return-in-non-void.patch: no longer needed.
- Drop vlc-avcodec-encoder-single-threaded.patch: fixed upstream.
- Drop ppc64_altivec.patch: fixed upstream.
* Sat Sep 21 2013 dimstar@opensuse.org
- Drop fluidsynt-devel BuildRequires: the fluid plugin is known to
  introduce a lot crashes at no gain from functionality PoV.
* Sat Sep  7 2013 dimstar@opensuse.org
- If we have a smblcient.pc available (meaning, we build against
  samba 4), we export the output of pkg-config --cflags smbclient
  into CFLAGS. Fixes build with Samba 4.0.
* Fri Aug  9 2013 dvaleev@suse.com
- Add ppc64_altivec.patch: Enable altivec for powerpc64
  (backport cce2cdb0dd246fa9669378f5a3b967464c88bf20)
- Add autoreconf call in build section, as above patch touches the
  build system.
* Fri Aug  9 2013 dvaleev@suse.com
- Package altivec plugins on powerpc
* Sat Aug  3 2013 dimstar@opensuse.org
- Update to version 2.0.8a:
  + always hide menu bar for fullscreen on osx redacted (vlc#9040).
  + macosx: fix double release
  + avcodec audio decoder: update block pointer.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 2.0.8:
  + Access:
  - Fix ISDB-S tuning.
  - Fix crash in QTsound.
  - Fix screen mouse file location.
  - Fix invalid memcpy in MMS access.
  + Demux:
  - Fix use after free in sgimb.
  - Improve resistance and checking against malformed MKV files.
  + Decoders:
  - Fix crash in the libavcodec module.
  + Mac OS X:
  - Fix interface crashes.
  - Fix autostart playback option.
  - Respect "playlist-autostart" option.
  + Updated translations.
- Drop vlc-vaapi.patch: fixed upstream.
- Add vlc-avcodec-encoder-single-threaded.patch: disable
  multithreading for avcodec encoder for now. Taken from git.
* Sun Jul 28 2013 reddwarf@opensuse.org
- Add pkgconfig(dirac) BuildRequires to enable Dirac support.
* Sat Jul 13 2013 dimstar@opensuse.org
- Add vlc-vaapi.patch: Make vaapi decoder compatible with latest
  libva changes.
* Thu Jul  4 2013 hrvoje.senjan@gmail.com
- Update to version 2.0.7:
  + Input:
  - Fix playback termination when switching ES tracks
    (PowerPC only)
  - Fix memory exhaustion vulnerability when playing specifically
    crafted playlist files
  + Decoders:
  - Fix WMA Pro, MPEG 4 ALS, APE, MLP and ADPCM-IMA4 playback
  + Encoders:
  - Fix audio encoding for numerous codecs, notably mp3 and aac
  + Muxers:
  - Fix noticeable memory leak when creating AVI files
  + Video output:
  - Fix crash when using libvlc in 3rd party applications
    (Mac only)
  + Mac OS X Interface
  - Minor improvements
  - Fix issue which could lead to loss of media files created
    through transcoding
* Tue Jun 11 2013 dvaleev@suse.com
- Enable SSE for x86 only
* Tue Jun  4 2013 reddwarf@opensuse.org
- Enable gme:
  + Pass --enable-gme to configure
  + Add pkgconfig(gme) BuildRequires
* Thu May  9 2013 dimstar@opensuse.org
- Enable opus codec:
  + Pass --enable-opus to configure
  + Add libopus-devel BuildRequires
* Tue May  7 2013 dimstar@opensuse.org
- Move live555-devel BuildRequires to the unconditional area:
  live555 has been added to Factory and is safe for distribution.
- Move the live555 demuxer from vlc-codecs to vlc-noX.
- Add unconditional --enable-live555 parameter to configure, and
  remove the conditional enable/remove-live555, based on BUILD_ORIG.
* Thu May  2 2013 dimstar@opensuse.org
- Add pkgconfig(libswscale) BuildRequires: improve the quality of
  the video filters.
- Unconditionally pass --enable-swscale to configure.
- Move the swscale videofilter out of the -codecs package to the
  - noX package.
* Thu Apr 25 2013 dimstar@opensuse.org
- Change libdvbpsi-devel BuildRequires to require version < 1.0.
  VLC 2.0.6 is not able to cope with the new API yet.
* Wed Apr 10 2013 dimstar@opensuse.org
- Change live555 BuildRequires to live555-devel: in fact we do
  require the devel package, which for historical reasons just
  happens to provide live555 as well.
* Tue Apr  9 2013 dimstar@opensuse.org
- Update to version 2.0.6:
  + Access:
  - Fix HTTPS playback with some certificates previously
    rejected.
  + Audio Output:
  - Fix lookup for device names in auhal plugin
  + Demuxers:
  - Fix crash with broken asf files (SA-1302)
  - Fix MKV behaviour with unknown or new ebml elements
  - Fix use-after-free crash in Ogg demuxer
  - Fix regression on some paletted codecs in AVI
  - Fix ALAC in mp4 regression
  - Improvements to the vimeo playlist parser
  + Decoders:
  - Fix GPU decoding on Intel HD 2000/3000 cards on Windows
  - Fix FLAC 6.1 and 7.1 channel layout
  - Fix crashes in HTML srt subtitles
  - 3rd party codecs updates
  + Mac OS X fixes
  + Qt: Fix clearing of Media Info panel on dialog exit
  + GNU/Linux:
  - Numerous D-Bus and MPRIS2 improvements
  - Reject broken versions of PulseAudio
  + Windows:
  - Fix uninstallation in different location than C:\
  + Updated translations.
* Thu Apr  4 2013 dimstar@opensuse.org
- Fix files section for openSUSE 11.4 and 12.1.
* Thu Apr  4 2013 dimstar@opensuse.org
- Introduce BUILD_ORIG build flag, in order to build without
  'legally difficult' extensions in OBS.
* Tue Jan 22 2013 dimstar@opensuse.org
- Add --enable-png configure parameter to enable png support
  (pointed out by Alin).
* Mon Dec 17 2012 dimstar@opensuse.org
- Add -msse to CFLAGS: this helps us over GCC 4.3 being used in
  SLE 11SP2.
* Sun Dec 16 2012 dimstar@opensuse.org
- Update to version 2.0.5:
  * See http://www.videolan.org/vlc/releases/2.0.5.html
* Sun Oct 21 2012 dimstar@opensuse.org
- Disable ncurses build: will need to work on finding the right
  ncursesw integration steps.
* Thu Oct 18 2012 dimstar@opensuse.org
- Update to version 2.0.4:
  + See NEWS for details.
* Thu Jul 19 2012 dimstar@opensuse.org
- Update to version 2.0.3
* Mon Jul  2 2012 dimstar@opensuse.org
- Upadate to version 2.0.2:
    Rework of the Mac OS X interface
    Fix video output for old graphic cards on Windows XP, which are using DirectX
    Fix video output on old Macs, notably PowerPC and GMA950 intel Macs.
    Support for HiDPI, aka Retina Display
    Support for H264 v4l2 devices on Linux
    Translations updates and new Scottish Gaelic translation
    Fixes for splitted RAR, MKV segmented, mp4 and Real media files playback.
    Rewrite of the Digital TV module on Windows
    Enhancements in HLS, Blu-Ray and various codecs support
    Fixes for subtitles auto-detection
    Fixes on Qt, skins2 and web interfaces
* Fri Mar 30 2012 dimstar@opensuse.org
- Inject -L%%{_libdir}/live into CFLAGS and CXXFLAGS for live555 to
  be built. The static lib is in a non-standard place and not
  detected by configure scripts.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 2.0.1:
  + Lots of bug fixes
  + For a full list, see NEWS file in the package.
* Fri Feb 17 2012 dimstar@opensuse.org
- Update to version 2.0.0 final.
* Wed Feb  1 2012 dimstar@opensuse.org
- Update to version 2.0.0 rc1
* Wed Jan 18 2012 dimstar@opensuse.org
- Add xorg-x11-devel BuildRequires: fixes build on Factory.
* Wed Jan 11 2012 dimstar@opensuse.org
- Use lua 5.1 on Factory.
* Thu Dec 22 2011 dimstar@opensuse.org
- Update to version 1.1.13:
  + This release was necessary due to a security issue in the TiVo
    demuxer.
* Fri Dec  2 2011 dimstar@opensuse.org
- Add libtool BuildRequires, as the chroot no longer implicitly
  provides it.
* Wed Nov 23 2011 dimstar@opensuse.org
- Build libva dependencies only for 11.4+.
* Fri Oct  7 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.12:
  + Audio outputs:
  - Mac OS X / auhal: multiple fixes for the Digital Audio output
    (S/PDIF) including support for OS X Lion
  - Multiple fixes and improved synchronization for PulseAudio
    support
  - Support for AC-3 and DTS passthrough with PulseAudio 1.0
  + Unix port:
  - Fix build compatibility with taglib < 1.6 and Xulrunner 1.9.1
  + Misc:
  - Fix crashes with Japanese locale on OS X
  - Minor fixes for Webplugin under Win32, AVI demuxer, smem and
    AudioScrobbler
  - Fix crash in HTTP and RTSP server (stream output or Web
    interface)
- Drop vlc-1.1.11-taglib.patch: Fixed upstream
* Wed Aug 24 2011 dominique-vlc.suse@leuenberger.net
- Add libgcrypt-devel BuildRequires.
* Mon Jul 18 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.11:
  + Security:
  - Fix buffer overflows in the RealMedia demuxer (CVE-2011-2587)
    and the AVI one (CVE-2011-2588).
  + Mozilla/ActiveX webplugin:
  - Fullscreen mode is fixed on Win32
  - Very simple fullscreen controller is visible on Win32
  + Demuxers/Meta Readers:
  - Better support for cover art embedded in mp4, wma
  + Muxers/Output:
  - Fix AVI muxer so the generated files are readable on other
    players
  + Extensions:
  - Multiple fixes for crashes and malfunctionning issues
  + Qt Interface:
  - Fix quitting on Linux
  - Fix opening of VIDEO_TS folders through the open disc dialog
    on Windows
  - Miscellaneous
  + Updated translations.
- Add vlc-1.1.11-taglib.patch: Fix build on openSUSE <= 11.2 with
  taglib 1.5.
* Mon Jul 11 2011 dominique-vlc.suse@leuenberger.net
- Remove PortAudio-devel BuildRequires. This is long obsolete.
* Tue Jun 14 2011 dominique-vlc.suse@leuenberger.net
- Update to 1.1.0
* Sun Apr  3 2011 dominique-vlc.suse@leuenberger.net
- Add vlc-youtube.patch: fix youtube playback. Hack patch from
  upstream git repository, commit id d938db.
* Tue Mar 15 2011 dominique-vlc.suse@leuenberger.net
- Update to 1.1.8:
  + Interfaces:
  - Oldrc interface is again the default RC interface, on Windows
  - Luarc, luahttp and luatelnet fixes
  - Qt and Mac OS X fixes
  - numerous Skins2 fixes, notably winamp2 skins
  + Encoder:
  - new libschroedinger-based Dirac codec encoder, faster than the
    current one
  + Access/Demuxers/Codecs:
  - Subtitles auto-detection is back for .txt files
  - vod/rtsp server and rtsp input fixes
  - mp4 demuxer improvements
  - ogg, rstp input, video filters minor fixes
  - taglib's replaygain is fixed for mp3
  - vobsub support has an improved auto-detection
  - fix a crash in malformed ape files
  + Miscellaneous fixes in:
  - Pulseaudio audio output, notably for usb cards
  - Stacktraces are now limited in size on Windows
  - Video resolution is now limited to 8192x8192, for security
    reasons (CORE-2011-0208)
  - Configure and build system improvements
  - DirectShow and BDA build headers have been updated
- Drop patches that came from upstream git:
  + vlc-matroska.patch
  + vlc-upnp-assert.patch
* Sat Mar 12 2011 dominique-vlc.suse@leuenberger.net
- Add 0001-KDE-Add-smb-to-the-supported-protocols-we-can-get-fi.patch
* Wed Feb 23 2011 dominique-vlc.suse@leuenberger.net
- Own _datadir/kde4/apps, so we do not have to rely on meta-
  package kde4-filesystem, which does not exist in Fedora.
- Remove kde4-filesystem BuildRequires.
* Sat Feb 19 2011 dominique-vlc.suse@leuenberger.net
- Add vlc-matroska.patch: Fix build with new matroska version.
  Multi Tag no longer exists.
* Mon Jan 31 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.7:
  + Linux port:
  - Integration with the KDE GUI platform is disabled due to KDE
  - bugs #234484 and #260719.
  + Mac OS X port:
    + Updated live555 library to fix playback of RTSP and Freebox
    streams
  + Running VLC in 64bit mode requires Mac OS X 10.6.0 or later for
    speed and stability reasons
  + Demuxers:
  - Fix for Matroska / WebM remote code execution vulnerability.
    VideoLAN-SA-1102
  + Updated translations.
- Changes from version 1.1.6.1:
  + Fix libnotify, lirc, pulse compilation and packaging for
    Unix/Linux
- Drop patches: vlc-lirc.patch and
  0001-Libnotify-depends-on-a-GTK-version-can-be-gtk-2.0-or.patch
* Mon Jan 24 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.6:
  + Audio output:
  - Multiple fixes and improvements on PulseAudio output
  + Access:
  - Fix the Audio CD crash when looking for CDDB metadata on
    Windows
  + Decoders:
  - Support for MPC SV7 and SV8 on Windows and Mac OS X (Unix was
    already working)
  - Enabled FluidSynth MIDI playback plugin on Mac OS X
  - Faster VP8/Webm decoding with recent codecs libraries
  + Demuxers:
  - Fix Buffer overflow in Real demuxer CVE-2010-3907 /
    VideoLAN-SA-1007
  - Fix some asf/wmv seeking issues, notably when seek didn't go
    to a keyframe
  - Support for 24-bits PCM over RTP (audio/L24)
  + Subtitles and renderer:
  - Do not auto-detect .txt files for subtitles
  - Mark more freetype options as safe
  - Mac OS X: fixed fontconfig cache creation
  - Fix heap corruption in subtitle decoders, potentially
    exploitable
  + Visualization:
  - Fix projectM visualization for Linux in all locales
  - Fix projectM visualization support for Windows
  - Various projectM improvements: the module should be working
    now
  - Fix goom crash on Windows XP and Mac OS X
  + Interfaces:
  - Qt4: fixes for media keys processing and MCE remotes
  - Qt4: various fixes and portability improvements
  - KDE: work-around open dialog first slow opening because of
    KMimeTypeRepository
  + Miscellaneous fixes:
  - KDE device solid actions
  - XDG screensaver
  - Transcode integer overflow
  - HTTP Icy metadata reading
  - Windows: revert to 1.1.4 performance timers
  + Updated translations.
- Add vlc-lirc.patch: fix build of the lirc module. Taken from git.
* Sun Jan 16 2011 dominique-vlc.suse@leuenberger.net
- No loner package locale co.
* Fri Nov 19 2010 dominique-vlc.suse@leuenberger.net
- Add vlc-upnp-assert.patch: fix build of upnp plugin.
* Sat Nov 13 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.5:
  + Security:
  - Fix a Windows crash on accessing Network Shared files/drives,
    VideoLAN-SA-1006
  + Services Discovery:
  - Integration in the playlist, of a list of web shows,
    provided by channels.com
  + Demuxers:
  - Game Music Emu (GME) plugin rewritten, using the proper C API
  - DVDnav and DVDread fixes for encoding and misc issues
  - Playback of live http .Webm streams
  - Taglib thread-safety fix
  + Decoders:
  - Fix decoding of H264 using DxVA2 using Intel IGP, thanks to
    the donation from "Puget Systems"
  + Skins:
  - Add an icon to VLC on Linux
  + Video Output:
  - fix a bug that could lead to 100%% CPU usage on XCB
  + Interfaces:
  - fix for Qt bug where VLC didn't exit properly on some Windows
    XP configuration
  - fixes on luatelnet and luarc
  + Miscellaneous crashes and fixes in various plugins (telnet,
    live555, theora and TS-mux, Qt)
  + libLVC:
  - add libvlc_media_new_fd() to play directly file descriptors
    (not Win32/Win64)
  - Miscellaneous fixes
  + Updated translations.
* Wed Oct 20 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.4.1:
  + Demuxers:
  - DVDnav and DVDread fixes for encoding and misc issues
  - Playback of live http .Webm streams
  + Decoders:
  - Fix decoding of H264 using DxVA2 using Intel IGP, thanks to
    the donation from "Puget Systems"
  + Skins:
  - add an icon to VLC
  + Uodated translations.
* Mon Sep  6 2010 dominique-vlc.suse@leuenberger.net
- Add libtwolame-devel BuildRequires
* Fri Aug 27 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.4:
  + Win32:
  - Fix a security issue when loading DLLs, especially in Qt4
    and dmo modules, See VideoLAN-SA-1005
  - Fix folders opening from the interface
  + Updated translations.
- Add gdk-pixbuf-devel BuildRequires for openSUSE 11.4+
- Add gtk2-devel BuildRequires and add new patch:
  0001-Libnotify-depends-on-a-GTK-version-can-be-gtk-2.0-or.patch
* Thu Aug 19 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.3:
  + Access and demuxers:
  - fixes for FTP relatives path and FTP directory support
  - fix for podcasts parsing
  - DVD: fix an assert error and various memory leaks
  + Taglib:
  - fix NULL dereferences, as reported by FortiGuard Lab,
    CVE-2010-2937 / VideoLAN-SA-1004
  + Playlist:
  - fix a regression where the wrong entry was played
  - fix m3u playlists exports
  + Skins2:
  - fix video autoresize behaviour
  + updated translations
* Tue Aug  3 2010 dominique-vlc.suse@leuenberger.net
- BuildRequire libmatroska-devel instead of libmatroska.
* Fri Jul 30 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.2:
  + Demuxers:
  - Avformat fps displaying fix
  - TS, fix an issue where some programs would get dropped
    (fixes DVB issues too)
  + Audio filters:
  * fix timestamps handling on some filters that provoqued issues
    when playback of mono streams, especially on Windows
  + Windows:
  - fix a bug in direct3d video output with old nVidia drivers
    that broke video playback with overlay (YUV->RGB)
  - fix console output encoding
  + Interface and extensions:
  - Youtube and other scripts updates
  - Misc fixes in Qt4 (especially VLM and EPG dialogs) and MacOS
    interface.
* Tue Jul 20 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.1:
  + libVLC:
  * Support for the new capabilities: libvlc_adjust_Enable,
    libvlc_adjust_Contrast, libvlc_adjust_Brightness,
    libvlc_adjust_Hue, libvlc_adjust_Saturation,
    libvlc_adjust_Gamma
  * Various fixes and crash preventions, especially when video
    functions were called early
  * libvlc_media_player_set_pause() can force the pause state,
    whereas libvlc_media_player_pause() would only toggle it.
  * libvlc_set_user_agent() configures the "user agent" strings
    used for some protocols (HTTP, PulseAudio...).
    This replaces the --http-user-agent and the former
  - -user-agent libvlc_new() parameters.
  * libvlc_video_set_callbacks() and libvlc_video_set_format()
    allow grabbing video frames from a chosen memory location in
    real-time.
    This replace the ugly --vmem-* libvlc_new() parameters in
    previous versions.
    See http://wiki.videolan.org/LibVLC_SampleCode_SDL as an
    example.
  * libvlc_audio_get_delay() and libvlc_audio_set_delay()
    configure the delay between audio and video/subpictures for
    the current input.
  + Stream output:
  * Fix h264 streaming in ts
  + Decoders/Demuxers:
  * Fix performance issues with GPU decoding using DxVA2 using
    ATI graphic cards You NEED ATI Catalyst 10.7
  * Fix :program selection in TS and DVB-T
  * Fixes and improvements for MKV, Avformat and Avcodec modules
  * Fix mod (.xm, .s3m, .it) files support on Windows and Mac
    builds
  + Linux port:
  * Fix pulse closing
  * VAAPI small improvements, notable for FourCC selection for
    extraction
  + Interfaces:
  * Qt: fix preferences, hotkeys, messages and some fulscreen
    behaviour
  * Skins: support for mousewheel in fullscreen, fix
    radialsliders
  * Http: fix fullscreen toggle
  + Updated translations.
* Sat Jul  3 2010 dominique-vlc.suse@leuenberger.net
- Add lirc-devel to BuildRequires to actually build the lirc
  interface. Thanks to Rob Verduijn for reporting this error.
* Mon Jun 21 2010 dominique-vlc.suse@leuenberger.net
- Update to 1.1.0:
  + This is a major release, adding major features, notably:
  - GPU and DSP decoding on selected platforms
  - New support for codecs, demuxers and muxers
  - Lua extensions and Lua content extensions (luaSD)
  - Improved interfaces
  - Video Output rework
  - Removal of lots of modules, rewrite of many
  - Improved performances, in CPU, RAM and I/O
  - New libVLC and bindings
  - New or improved ports on misc platforms
  + And so many bugs and other features...
* Wed Jun 16 2010 dominique-vlc.suse@leuenberger.net
- Update to rc4
* Fri Jun 11 2010 dominique-vlc.suse@leuenberger.net
- Update to rc2
- BuildRequires SDL_image-devel
- Remove obsoleted switches from configure call.
* Thu Jun 10 2010 dominique-vlc.suse@leuenberger.net
- Add git-rollup.patch.bz2 to rollup to current git. Supposed
  to fix various crashers we see lately in 1.1rc2.
* Tue Jun  8 2010 dominique-vlc.suse@leuenberger.net
- BuildRequire libva-devel on openSUSE 11.2+
* Sun Jun  6 2010 dominique-vlc.suse@leuenberger.net
- Update to 1.1.0 RC 2: Final to be expected soon.
* Wed May 26 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.0 RC
* Mon Apr 26 2010 root@localhost
- BuildRequire appropriate xulrunner version.
* Sat Apr 24 2010 dominique-vlc.suse@leuenberger.net
- Patched tarball uploaded, as older versions of openSUSE
  seem not able to properly bootstrap it. The patch applied to the
  source tarball is vlc-globalhotkey-with-old-xcb-keysyms.patch.
* Fri Apr 23 2010 dominique-vlc.suse@leuenberger.net
- Add vlc-libpng14.patch, taken from git master, commit ffa6a2f.
* Thu Apr 22 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.6:
  + Access:
  * Fix crash on FTP URI with no file path
  + Decoders/Packetizers:
  * Fix overflows in A/52, DTS, MPEG Audio and subtitles support
  + Demuxers:
  * Update LUA script for Youtube pages
  * Fix crashes in AVI, ASF and Matroska files
  * Fix crashes on malformatted ZIP archives
  * Fix crashes and leaks in the FFmpeg/avformat plugin
  * Fix crash on invalid XSPF playlist
  + X11 port:
  * Partial Xlib threading fixes
  + Interfaces:
  * Fix crash (use after free) in Qt4 bookmarks
  * Fix a few crashes in Qt4 playlist
  + Removed modules:
    RTMP input and output are removed due to security problems.
    Please update to VLC 1.1.0 which provides an FFmpeg-based RTMP
    input if needed.
  + Updated translations.
- Changes from version 1.0.5:
  + Decoders:
  * SubRip extra styles improvements
  * Fix potential crashes in SSA and svg decoders
  + Mac OS X Interface:
  * Improved support for the 2009 Apple Remote
  + Windows port:
  * Use of gcc 4.4.2 to compile instead of gcc 4.2. This might
    slightly increase performance and fix x264 issues
* Thu Dec 10 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.4:
  + Audio outputs:
  * Fix deadlocks in the audio output core
  * Make PulseAudio the default output if available
  + Video outputs:
  * Fix fullscreen mode with KDE 4.3.3 and other window managers
  * Fix incompatibility with cairo-dock and compositing
  + Input:
  * Fix DVB scanning regression from VLC 1.0.3
  * Support for XZ-compressed byte stream (LZMA algorithm)
  + Playlist:
  * Support for .m3u8 playlist files (UTF-8 M3U)
  + Unix:
  * Support for xcb-keysyms version 0.3.4 or higher
  * Fix globalhotkeys on FreeBSD
  + Qt4 interface:
  * Fix opening V4L version 1 devices
  * Fix default destination ports in the streaming wizard
* Fri Oct 30 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.3
  + Video outputs:
  - Fix video quality when resizing the video on Windows Vista
    and 7, due to regressions in most popular drivers
  - New deinterlacers modules based on yadif and yadif(x2)
    algorithms
  + Decoders:
  - Windows version supports now natively the WMA Professional
    codec, as it didn't work in the packaged version of 1.0.2
  - Fix downmixing of particual 4.0 AC-3 audio tracks
  + Encoders:
  - x264 has profile-limitter, like:
    [#]transcode{vcodec=h264,venc=x264{profile=baseline,level=12}..}
  + Input:
  - Update for appletrailers lua script
  - Fixes on the RAR stream filter
  - Fix for E-AC3 in ATSC/TS streams
  - Various fixes for v4l and v4l2
  - Fix a crash in mjpeg demuxer
  + Service discovery:
  - New udev module for Linux
  + Qt4 interface:
  - Fixes on the playlist and the stream output panels
  + Updated translations.
* Tue Sep 29 2009 dominique-vlc.suse@leuenberger.net
- Add 540_all_x264.patch to build with x264 >= 0.76. Patch copied
  from gentoo portage.
* Mon Sep 21 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.2
  + Decoders:
  - Native support for WMA Professional, without the use of the
    Win32 dlls
  - Fix issues in subtitles, especially SSA ones
  - Various fixes on theora and ogg
  + Demuxers:
  - Various fixes for EPG support in MPEG-TS demuxer
  - Fixes for potential stack overflow in .avi, .mp4 and .asf
    demuxers
  + Access:
  - Fixes for v4l2 devices
  - Fixes for dvb-c channels-scanning
  + Qt Interface:
  - Fix some playlist sorting issues
  + Encoders:
  - MPEG2 transrate stream output removed
  - x264 default-values closer to x264.exe defaults.
  - x264 rc-behaviour fixes:
    . if user defines qp-value, CQP-mode is used
    . otherwise if user defines vb=0, CRF-mode is used
    . otherwise ABR-mode is used
  - x264 set vbv-bufsize/vbv-maxsize better if user hasn't
    defined these:
    . ABR mode set vbv-max-bitrate=bitrate
    . vbv-bufsize is bitrate * seconds between keyframes
    (keyint/fps)
  + Playlist:
  - Lua scripts for Mpora and Vimeo playback
  + Updated translations.
* Mon Aug 17 2009 dominique-vlc.suse@leuenberger.net
- Add vlc-1.0.1-libass4.patch to support newer libass. Patch
  taken from upstream commit 019359b5a5.
* Mon Jul 27 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.1
  + Demuxers:
  * Fix wmv/asf issues that caused audio to drop
  * Various fixes for ac3, mp3, dts and stability for wav format
  * Fix seek in RTSP in conformity to RFC 2326
  * Fix Dailymotion access script
  * Fix crashes in xspf files handler
  * Fix seeking and timing issues in some flv files on Windows
    version
  + Access:
  * Add extra caching for files on network shares
  * Prevent integer underflow in Real pseudo-RTSP module,
    discovered by tixxDZ, DZCORE Labs, Algeria
  + Decoders:
  * Fix seeking in mpeg2 video files
  * Improve SSA subtitles rendering
  * Update most codecs for the Windows and Mac version
  + Muxers:
  * Fix sound recording of .flv files with mp3 audio
  + Qt Interface:
  * Possibility to change the opacity level of the Fullscreen
    controller
  * Fix various crashes and VIDEO_TS folders opening
  + Mac OS X Interface:
  * Added options to disable support for Apple Remote and Media
    Keys
  * Fixed options for Volume, Last.fm password and Subtitle
    Encoding
  * Fixed redraw issues when autosizing the video window
  * Preferences panel now includes help through tool-tips
  * More reliable Information and Messages panels
  * Fix various crashes
  + Windows port:
  * The ZVBI module is now available for Windows, for complete
    teletext support
  + Update translations.
* Tue Jul  7 2009 dominique-vlc.suse@leuenberger.net
- Update to 1.0.0
  * See http://git.videolan.org/?p=vlc.git;a=blob;f=NEWS;h=777764
* Thu Jun 18 2009 dominique-vlc.suse@leuenberger.net
- Update to 1.0.0-rc4
  Notable fixes:
  - Mac OS crashes
  - Qt Fullscreen controllers
  - libass, playlist and skins crashes
  - dv update to new API
  - TrueHD in M2TS
- dropped vlc-xulrunner191 patch; it was merged upstream
* Sat May 30 2009 dominique-vlc.suse@leuenberger.net
- Add vlc-xulrunner191 patch (conditional. Works only with xul 191)
